"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListCodeRepositories = void 0;
const ListCodeRepositoriesCommand_1 = require("../commands/ListCodeRepositoriesCommand");
const SageMaker_1 = require("../SageMaker");
const SageMakerClient_1 = require("../SageMakerClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListCodeRepositoriesCommand_1.ListCodeRepositoriesCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listCodeRepositories(input, ...args);
};
async function* paginateListCodeRepositories(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof SageMaker_1.SageMaker) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof SageMakerClient_1.SageMakerClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected SageMaker | SageMakerClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListCodeRepositories = paginateListCodeRepositories;
