"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListEndpoints = void 0;
const ListEndpointsCommand_1 = require("../commands/ListEndpointsCommand");
const SageMaker_1 = require("../SageMaker");
const SageMakerClient_1 = require("../SageMakerClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListEndpointsCommand_1.ListEndpointsCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listEndpoints(input, ...args);
};
async function* paginateListEndpoints(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof SageMaker_1.SageMaker) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof SageMakerClient_1.SageMakerClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected SageMaker | SageMakerClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListEndpoints = paginateListEndpoints;
