"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.waitUntilImageDeleted = exports.waitForImageDeleted = void 0;
const util_waiter_1 = require("@aws-sdk/util-waiter");
const DescribeImageCommand_1 = require("../commands/DescribeImageCommand");
const checkState = async (client, input) => {
    let reason;
    try {
        const result = await client.send(new DescribeImageCommand_1.DescribeImageCommand(input));
        reason = result;
        try {
            const returnComparator = () => {
                return result.ImageStatus;
            };
            if (returnComparator() === "DELETE_FAILED") {
                return { state: util_waiter_1.WaiterState.FAILURE, reason };
            }
        }
        catch (e) { }
    }
    catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "ResourceNotFoundException") {
            return { state: util_waiter_1.WaiterState.SUCCESS, reason };
        }
        if (exception.name && exception.name == "ValidationException") {
            return { state: util_waiter_1.WaiterState.FAILURE, reason };
        }
    }
    return { state: util_waiter_1.WaiterState.RETRY, reason };
};
const waitForImageDeleted = async (params, input) => {
    const serviceDefaults = { minDelay: 60, maxDelay: 120 };
    return (0, util_waiter_1.createWaiter)({ ...serviceDefaults, ...params }, input, checkState);
};
exports.waitForImageDeleted = waitForImageDeleted;
const waitUntilImageDeleted = async (params, input) => {
    const serviceDefaults = { minDelay: 60, maxDelay: 120 };
    const result = await (0, util_waiter_1.createWaiter)({ ...serviceDefaults, ...params }, input, checkState);
    return (0, util_waiter_1.checkExceptions)(result);
};
exports.waitUntilImageDeleted = waitUntilImageDeleted;
