import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { BatchDescribeModelPackageInput, BatchDescribeModelPackageOutput } from "../models/models_0";
import { SageMakerClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../SageMakerClient";
export interface BatchDescribeModelPackageCommandInput extends BatchDescribeModelPackageInput {
}
export interface BatchDescribeModelPackageCommandOutput extends BatchDescribeModelPackageOutput, __MetadataBearer {
}
/**
 * <p>This action batch describes a list of versioned model packages</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SageMakerClient, BatchDescribeModelPackageCommand } from "@aws-sdk/client-sagemaker"; // ES Modules import
 * // const { SageMakerClient, BatchDescribeModelPackageCommand } = require("@aws-sdk/client-sagemaker"); // CommonJS import
 * const client = new SageMakerClient(config);
 * const command = new BatchDescribeModelPackageCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link BatchDescribeModelPackageCommandInput} for command's `input` shape.
 * @see {@link BatchDescribeModelPackageCommandOutput} for command's `response` shape.
 * @see {@link SageMakerClientResolvedConfig | config} for SageMakerClient's `config` shape.
 *
 */
export declare class BatchDescribeModelPackageCommand extends $Command<BatchDescribeModelPackageCommandInput, BatchDescribeModelPackageCommandOutput, SageMakerClientResolvedConfig> {
    readonly input: BatchDescribeModelPackageCommandInput;
    constructor(input: BatchDescribeModelPackageCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: SageMakerClientResolvedConfig, options?: __HttpHandlerOptions): Handler<BatchDescribeModelPackageCommandInput, BatchDescribeModelPackageCommandOutput>;
    private serialize;
    private deserialize;
}
