import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DescribeLineageGroupRequest, DescribeLineageGroupResponse } from "../models/models_1";
import { SageMakerClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../SageMakerClient";
export interface DescribeLineageGroupCommandInput extends DescribeLineageGroupRequest {
}
export interface DescribeLineageGroupCommandOutput extends DescribeLineageGroupResponse, __MetadataBearer {
}
/**
 * <p>Provides a list of properties for the requested lineage group.
 *          For more information, see <a href="https://docs.aws.amazon.com/sagemaker/latest/dg/xaccount-lineage-tracking.html">
 *             Cross-Account Lineage Tracking </a> in the <i>Amazon SageMaker Developer Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SageMakerClient, DescribeLineageGroupCommand } from "@aws-sdk/client-sagemaker"; // ES Modules import
 * // const { SageMakerClient, DescribeLineageGroupCommand } = require("@aws-sdk/client-sagemaker"); // CommonJS import
 * const client = new SageMakerClient(config);
 * const command = new DescribeLineageGroupCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribeLineageGroupCommandInput} for command's `input` shape.
 * @see {@link DescribeLineageGroupCommandOutput} for command's `response` shape.
 * @see {@link SageMakerClientResolvedConfig | config} for SageMakerClient's `config` shape.
 *
 */
export declare class DescribeLineageGroupCommand extends $Command<DescribeLineageGroupCommandInput, DescribeLineageGroupCommandOutput, SageMakerClientResolvedConfig> {
    readonly input: DescribeLineageGroupCommandInput;
    constructor(input: DescribeLineageGroupCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: SageMakerClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribeLineageGroupCommandInput, DescribeLineageGroupCommandOutput>;
    private serialize;
    private deserialize;
}
