import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { ListLineageGroupsRequest, ListLineageGroupsResponse } from "../models/models_2";
import { SageMakerClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../SageMakerClient";
export interface ListLineageGroupsCommandInput extends ListLineageGroupsRequest {
}
export interface ListLineageGroupsCommandOutput extends ListLineageGroupsResponse, __MetadataBearer {
}
/**
 * <p>A list of lineage groups shared with your Amazon Web Services account.
 *          For more information, see <a href="https://docs.aws.amazon.com/sagemaker/latest/dg/xaccount-lineage-tracking.html">
 *             Cross-Account Lineage Tracking </a> in the <i>Amazon SageMaker Developer Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SageMakerClient, ListLineageGroupsCommand } from "@aws-sdk/client-sagemaker"; // ES Modules import
 * // const { SageMakerClient, ListLineageGroupsCommand } = require("@aws-sdk/client-sagemaker"); // CommonJS import
 * const client = new SageMakerClient(config);
 * const command = new ListLineageGroupsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ListLineageGroupsCommandInput} for command's `input` shape.
 * @see {@link ListLineageGroupsCommandOutput} for command's `response` shape.
 * @see {@link SageMakerClientResolvedConfig | config} for SageMakerClient's `config` shape.
 *
 */
export declare class ListLineageGroupsCommand extends $Command<ListLineageGroupsCommandInput, ListLineageGroupsCommandOutput, SageMakerClientResolvedConfig> {
    readonly input: ListLineageGroupsCommandInput;
    constructor(input: ListLineageGroupsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: SageMakerClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ListLineageGroupsCommandInput, ListLineageGroupsCommandOutput>;
    private serialize;
    private deserialize;
}
