import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { ListModelMetadataRequest, ListModelMetadataResponse } from "../models/models_2";
import { SageMakerClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../SageMakerClient";
export interface ListModelMetadataCommandInput extends ListModelMetadataRequest {
}
export interface ListModelMetadataCommandOutput extends ListModelMetadataResponse, __MetadataBearer {
}
/**
 * <p>Lists the domain, framework, task, and model name of standard
 *           machine learning models found in common model zoos.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SageMakerClient, ListModelMetadataCommand } from "@aws-sdk/client-sagemaker"; // ES Modules import
 * // const { SageMakerClient, ListModelMetadataCommand } = require("@aws-sdk/client-sagemaker"); // CommonJS import
 * const client = new SageMakerClient(config);
 * const command = new ListModelMetadataCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ListModelMetadataCommandInput} for command's `input` shape.
 * @see {@link ListModelMetadataCommandOutput} for command's `response` shape.
 * @see {@link SageMakerClientResolvedConfig | config} for SageMakerClient's `config` shape.
 *
 */
export declare class ListModelMetadataCommand extends $Command<ListModelMetadataCommandInput, ListModelMetadataCommandOutput, SageMakerClientResolvedConfig> {
    readonly input: ListModelMetadataCommandInput;
    constructor(input: ListModelMetadataCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: SageMakerClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ListModelMetadataCommandInput, ListModelMetadataCommandOutput>;
    private serialize;
    private deserialize;
}
