import { ExceptionOptionType as __ExceptionOptionType, LazyJsonString as __LazyJsonString } from "@aws-sdk/smithy-client";
import { SageMakerServiceException as __BaseException } from "./SageMakerServiceException";

export interface ActionSource {
    
    SourceUri: string | undefined;
    
    SourceType?: string;
    
    SourceId?: string;
}
export declare namespace ActionSource {
    
    const filterSensitiveLog: (obj: ActionSource) => any;
}
export declare enum ActionStatus {
    COMPLETED = "Completed",
    FAILED = "Failed",
    IN_PROGRESS = "InProgress",
    STOPPED = "Stopped",
    STOPPING = "Stopping",
    UNKNOWN = "Unknown"
}

export interface ActionSummary {
    
    ActionArn?: string;
    
    ActionName?: string;
    
    Source?: ActionSource;
    
    ActionType?: string;
    
    Status?: ActionStatus | string;
    
    CreationTime?: Date;
    
    LastModifiedTime?: Date;
}
export declare namespace ActionSummary {
    
    const filterSensitiveLog: (obj: ActionSummary) => any;
}
export declare enum AssociationEdgeType {
    ASSOCIATED_WITH = "AssociatedWith",
    CONTRIBUTED_TO = "ContributedTo",
    DERIVED_FROM = "DerivedFrom",
    PRODUCED = "Produced"
}
export interface AddAssociationRequest {
    
    SourceArn: string | undefined;
    
    DestinationArn: string | undefined;
    
    AssociationType?: AssociationEdgeType | string;
}
export declare namespace AddAssociationRequest {
    
    const filterSensitiveLog: (obj: AddAssociationRequest) => any;
}
export interface AddAssociationResponse {
    
    SourceArn?: string;
    
    DestinationArn?: string;
}
export declare namespace AddAssociationResponse {
    
    const filterSensitiveLog: (obj: AddAssociationResponse) => any;
}

export declare class ResourceLimitExceeded extends __BaseException {
    readonly name: "ResourceLimitExceeded";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ResourceLimitExceeded, __BaseException>);
}

export declare class ResourceNotFound extends __BaseException {
    readonly name: "ResourceNotFound";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ResourceNotFound, __BaseException>);
}

export interface ModelInput {
    
    DataInputConfig: string | undefined;
}
export declare namespace ModelInput {
    
    const filterSensitiveLog: (obj: ModelInput) => any;
}

export interface ModelPackageContainerDefinition {
    
    ContainerHostname?: string;
    
    Image: string | undefined;
    
    ImageDigest?: string;
    
    ModelDataUrl?: string;
    
    ProductId?: string;
    
    Environment?: {
        [key: string]: string;
    };
    
    ModelInput?: ModelInput;
    
    Framework?: string;
    
    FrameworkVersion?: string;
    
    NearestModelName?: string;
}
export declare namespace ModelPackageContainerDefinition {
    
    const filterSensitiveLog: (obj: ModelPackageContainerDefinition) => any;
}
export declare enum ProductionVariantInstanceType {
    ML_C4_2XLARGE = "ml.c4.2xlarge",
    ML_C4_4XLARGE = "ml.c4.4xlarge",
    ML_C4_8XLARGE = "ml.c4.8xlarge",
    ML_C4_LARGE = "ml.c4.large",
    ML_C4_XLARGE = "ml.c4.xlarge",
    ML_C5D_18XLARGE = "ml.c5d.18xlarge",
    ML_C5D_2XLARGE = "ml.c5d.2xlarge",
    ML_C5D_4XLARGE = "ml.c5d.4xlarge",
    ML_C5D_9XLARGE = "ml.c5d.9xlarge",
    ML_C5D_LARGE = "ml.c5d.large",
    ML_C5D_XLARGE = "ml.c5d.xlarge",
    ML_C5_18XLARGE = "ml.c5.18xlarge",
    ML_C5_2XLARGE = "ml.c5.2xlarge",
    ML_C5_4XLARGE = "ml.c5.4xlarge",
    ML_C5_9XLARGE = "ml.c5.9xlarge",
    ML_C5_LARGE = "ml.c5.large",
    ML_C5_XLARGE = "ml.c5.xlarge",
    ML_G4DN_12XLARGE = "ml.g4dn.12xlarge",
    ML_G4DN_16XLARGE = "ml.g4dn.16xlarge",
    ML_G4DN_2XLARGE = "ml.g4dn.2xlarge",
    ML_G4DN_4XLARGE = "ml.g4dn.4xlarge",
    ML_G4DN_8XLARGE = "ml.g4dn.8xlarge",
    ML_G4DN_XLARGE = "ml.g4dn.xlarge",
    ML_INF1_24XLARGE = "ml.inf1.24xlarge",
    ML_INF1_2XLARGE = "ml.inf1.2xlarge",
    ML_INF1_6XLARGE = "ml.inf1.6xlarge",
    ML_INF1_XLARGE = "ml.inf1.xlarge",
    ML_M4_10XLARGE = "ml.m4.10xlarge",
    ML_M4_16XLARGE = "ml.m4.16xlarge",
    ML_M4_2XLARGE = "ml.m4.2xlarge",
    ML_M4_4XLARGE = "ml.m4.4xlarge",
    ML_M4_XLARGE = "ml.m4.xlarge",
    ML_M5D_12XLARGE = "ml.m5d.12xlarge",
    ML_M5D_24XLARGE = "ml.m5d.24xlarge",
    ML_M5D_2XLARGE = "ml.m5d.2xlarge",
    ML_M5D_4XLARGE = "ml.m5d.4xlarge",
    ML_M5D_LARGE = "ml.m5d.large",
    ML_M5D_XLARGE = "ml.m5d.xlarge",
    ML_M5_12XLARGE = "ml.m5.12xlarge",
    ML_M5_24XLARGE = "ml.m5.24xlarge",
    ML_M5_2XLARGE = "ml.m5.2xlarge",
    ML_M5_4XLARGE = "ml.m5.4xlarge",
    ML_M5_LARGE = "ml.m5.large",
    ML_M5_XLARGE = "ml.m5.xlarge",
    ML_P2_16XLARGE = "ml.p2.16xlarge",
    ML_P2_8XLARGE = "ml.p2.8xlarge",
    ML_P2_XLARGE = "ml.p2.xlarge",
    ML_P3_16XLARGE = "ml.p3.16xlarge",
    ML_P3_2XLARGE = "ml.p3.2xlarge",
    ML_P3_8XLARGE = "ml.p3.8xlarge",
    ML_R5D_12XLARGE = "ml.r5d.12xlarge",
    ML_R5D_24XLARGE = "ml.r5d.24xlarge",
    ML_R5D_2XLARGE = "ml.r5d.2xlarge",
    ML_R5D_4XLARGE = "ml.r5d.4xlarge",
    ML_R5D_LARGE = "ml.r5d.large",
    ML_R5D_XLARGE = "ml.r5d.xlarge",
    ML_R5_12XLARGE = "ml.r5.12xlarge",
    ML_R5_24XLARGE = "ml.r5.24xlarge",
    ML_R5_2XLARGE = "ml.r5.2xlarge",
    ML_R5_4XLARGE = "ml.r5.4xlarge",
    ML_R5_LARGE = "ml.r5.large",
    ML_R5_XLARGE = "ml.r5.xlarge",
    ML_T2_2XLARGE = "ml.t2.2xlarge",
    ML_T2_LARGE = "ml.t2.large",
    ML_T2_MEDIUM = "ml.t2.medium",
    ML_T2_XLARGE = "ml.t2.xlarge"
}
export declare enum TransformInstanceType {
    ML_C4_2XLARGE = "ml.c4.2xlarge",
    ML_C4_4XLARGE = "ml.c4.4xlarge",
    ML_C4_8XLARGE = "ml.c4.8xlarge",
    ML_C4_XLARGE = "ml.c4.xlarge",
    ML_C5_18XLARGE = "ml.c5.18xlarge",
    ML_C5_2XLARGE = "ml.c5.2xlarge",
    ML_C5_4XLARGE = "ml.c5.4xlarge",
    ML_C5_9XLARGE = "ml.c5.9xlarge",
    ML_C5_XLARGE = "ml.c5.xlarge",
    ML_G4DN_12XLARGE = "ml.g4dn.12xlarge",
    ML_G4DN_16XLARGE = "ml.g4dn.16xlarge",
    ML_G4DN_2XLARGE = "ml.g4dn.2xlarge",
    ML_G4DN_4XLARGE = "ml.g4dn.4xlarge",
    ML_G4DN_8XLARGE = "ml.g4dn.8xlarge",
    ML_G4DN_XLARGE = "ml.g4dn.xlarge",
    ML_M4_10XLARGE = "ml.m4.10xlarge",
    ML_M4_16XLARGE = "ml.m4.16xlarge",
    ML_M4_2XLARGE = "ml.m4.2xlarge",
    ML_M4_4XLARGE = "ml.m4.4xlarge",
    ML_M4_XLARGE = "ml.m4.xlarge",
    ML_M5_12XLARGE = "ml.m5.12xlarge",
    ML_M5_24XLARGE = "ml.m5.24xlarge",
    ML_M5_2XLARGE = "ml.m5.2xlarge",
    ML_M5_4XLARGE = "ml.m5.4xlarge",
    ML_M5_LARGE = "ml.m5.large",
    ML_M5_XLARGE = "ml.m5.xlarge",
    ML_P2_16XLARGE = "ml.p2.16xlarge",
    ML_P2_8XLARGE = "ml.p2.8xlarge",
    ML_P2_XLARGE = "ml.p2.xlarge",
    ML_P3_16XLARGE = "ml.p3.16xlarge",
    ML_P3_2XLARGE = "ml.p3.2xlarge",
    ML_P3_8XLARGE = "ml.p3.8xlarge"
}

export interface AdditionalInferenceSpecificationDefinition {
    
    Name: string | undefined;
    
    Description?: string;
    
    Containers: ModelPackageContainerDefinition[] | undefined;
    
    SupportedTransformInstanceTypes?: (TransformInstanceType | string)[];
    
    SupportedRealtimeInferenceInstanceTypes?: (ProductionVariantInstanceType | string)[];
    
    SupportedContentTypes?: string[];
    
    SupportedResponseMIMETypes?: string[];
}
export declare namespace AdditionalInferenceSpecificationDefinition {
    
    const filterSensitiveLog: (obj: AdditionalInferenceSpecificationDefinition) => any;
}

export interface Tag {
    
    Key: string | undefined;
    
    Value: string | undefined;
}
export declare namespace Tag {
    
    const filterSensitiveLog: (obj: Tag) => any;
}
export interface AddTagsInput {
    
    ResourceArn: string | undefined;
    
    Tags: Tag[] | undefined;
}
export declare namespace AddTagsInput {
    
    const filterSensitiveLog: (obj: AddTagsInput) => any;
}
export interface AddTagsOutput {
    
    Tags?: Tag[];
}
export declare namespace AddTagsOutput {
    
    const filterSensitiveLog: (obj: AddTagsOutput) => any;
}

export interface AgentVersion {
    
    Version: string | undefined;
    
    AgentCount: number | undefined;
}
export declare namespace AgentVersion {
    
    const filterSensitiveLog: (obj: AgentVersion) => any;
}

export interface Alarm {
    
    AlarmName?: string;
}
export declare namespace Alarm {
    
    const filterSensitiveLog: (obj: Alarm) => any;
}
export declare enum AlgorithmSortBy {
    CREATION_TIME = "CreationTime",
    NAME = "Name"
}

export interface MetricDefinition {
    
    Name: string | undefined;
    
    Regex: string | undefined;
}
export declare namespace MetricDefinition {
    
    const filterSensitiveLog: (obj: MetricDefinition) => any;
}
export declare enum TrainingInputMode {
    FASTFILE = "FastFile",
    FILE = "File",
    PIPE = "Pipe"
}

export interface AlgorithmSpecification {
    
    TrainingImage?: string;
    
    AlgorithmName?: string;
    
    TrainingInputMode: TrainingInputMode | string | undefined;
    
    MetricDefinitions?: MetricDefinition[];
    
    EnableSageMakerMetricsTimeSeries?: boolean;
}
export declare namespace AlgorithmSpecification {
    
    const filterSensitiveLog: (obj: AlgorithmSpecification) => any;
}
export declare enum AlgorithmStatus {
    COMPLETED = "Completed",
    DELETING = "Deleting",
    FAILED = "Failed",
    IN_PROGRESS = "InProgress",
    PENDING = "Pending"
}
export declare enum DetailedAlgorithmStatus {
    COMPLETED = "Completed",
    FAILED = "Failed",
    IN_PROGRESS = "InProgress",
    NOT_STARTED = "NotStarted"
}

export interface AlgorithmStatusItem {
    
    Name: string | undefined;
    
    Status: DetailedAlgorithmStatus | string | undefined;
    
    FailureReason?: string;
}
export declare namespace AlgorithmStatusItem {
    
    const filterSensitiveLog: (obj: AlgorithmStatusItem) => any;
}

export interface AlgorithmStatusDetails {
    
    ValidationStatuses?: AlgorithmStatusItem[];
    
    ImageScanStatuses?: AlgorithmStatusItem[];
}
export declare namespace AlgorithmStatusDetails {
    
    const filterSensitiveLog: (obj: AlgorithmStatusDetails) => any;
}

export interface AlgorithmSummary {
    
    AlgorithmName: string | undefined;
    
    AlgorithmArn: string | undefined;
    
    AlgorithmDescription?: string;
    
    CreationTime: Date | undefined;
    
    AlgorithmStatus: AlgorithmStatus | string | undefined;
}
export declare namespace AlgorithmSummary {
    
    const filterSensitiveLog: (obj: AlgorithmSummary) => any;
}
export declare enum CompressionType {
    GZIP = "Gzip",
    NONE = "None"
}
export declare enum FileSystemAccessMode {
    RO = "ro",
    RW = "rw"
}
export declare enum FileSystemType {
    EFS = "EFS",
    FSXLUSTRE = "FSxLustre"
}

export interface FileSystemDataSource {
    
    FileSystemId: string | undefined;
    
    FileSystemAccessMode: FileSystemAccessMode | string | undefined;
    
    FileSystemType: FileSystemType | string | undefined;
    
    DirectoryPath: string | undefined;
}
export declare namespace FileSystemDataSource {
    
    const filterSensitiveLog: (obj: FileSystemDataSource) => any;
}
export declare enum S3DataDistribution {
    FULLY_REPLICATED = "FullyReplicated",
    SHARDED_BY_S3_KEY = "ShardedByS3Key"
}
export declare enum S3DataType {
    AUGMENTED_MANIFEST_FILE = "AugmentedManifestFile",
    MANIFEST_FILE = "ManifestFile",
    S3_PREFIX = "S3Prefix"
}

export interface S3DataSource {
    
    S3DataType: S3DataType | string | undefined;
    
    S3Uri: string | undefined;
    
    S3DataDistributionType?: S3DataDistribution | string;
    
    AttributeNames?: string[];
}
export declare namespace S3DataSource {
    
    const filterSensitiveLog: (obj: S3DataSource) => any;
}

export interface DataSource {
    
    S3DataSource?: S3DataSource;
    
    FileSystemDataSource?: FileSystemDataSource;
}
export declare namespace DataSource {
    
    const filterSensitiveLog: (obj: DataSource) => any;
}
export declare enum RecordWrapper {
    NONE = "None",
    RECORDIO = "RecordIO"
}

export interface ShuffleConfig {
    
    Seed: number | undefined;
}
export declare namespace ShuffleConfig {
    
    const filterSensitiveLog: (obj: ShuffleConfig) => any;
}

export interface Channel {
    
    ChannelName: string | undefined;
    
    DataSource: DataSource | undefined;
    
    ContentType?: string;
    
    CompressionType?: CompressionType | string;
    
    RecordWrapperType?: RecordWrapper | string;
    
    InputMode?: TrainingInputMode | string;
    
    ShuffleConfig?: ShuffleConfig;
}
export declare namespace Channel {
    
    const filterSensitiveLog: (obj: Channel) => any;
}

export interface OutputDataConfig {
    
    KmsKeyId?: string;
    
    S3OutputPath: string | undefined;
}
export declare namespace OutputDataConfig {
    
    const filterSensitiveLog: (obj: OutputDataConfig) => any;
}
export declare enum TrainingInstanceType {
    ML_C4_2XLARGE = "ml.c4.2xlarge",
    ML_C4_4XLARGE = "ml.c4.4xlarge",
    ML_C4_8XLARGE = "ml.c4.8xlarge",
    ML_C4_XLARGE = "ml.c4.xlarge",
    ML_C5N_18XLARGE = "ml.c5n.18xlarge",
    ML_C5N_2XLARGE = "ml.c5n.2xlarge",
    ML_C5N_4XLARGE = "ml.c5n.4xlarge",
    ML_C5N_9XLARGE = "ml.c5n.9xlarge",
    ML_C5N_XLARGE = "ml.c5n.xlarge",
    ML_C5_18XLARGE = "ml.c5.18xlarge",
    ML_C5_2XLARGE = "ml.c5.2xlarge",
    ML_C5_4XLARGE = "ml.c5.4xlarge",
    ML_C5_9XLARGE = "ml.c5.9xlarge",
    ML_C5_XLARGE = "ml.c5.xlarge",
    ML_G4DN_12XLARGE = "ml.g4dn.12xlarge",
    ML_G4DN_16XLARGE = "ml.g4dn.16xlarge",
    ML_G4DN_2XLARGE = "ml.g4dn.2xlarge",
    ML_G4DN_4XLARGE = "ml.g4dn.4xlarge",
    ML_G4DN_8XLARGE = "ml.g4dn.8xlarge",
    ML_G4DN_XLARGE = "ml.g4dn.xlarge",
    ML_G5_12XLARGE = "ml.g5.12xlarge",
    ML_G5_16XLARGE = "ml.g5.16xlarge",
    ML_G5_24XLARGE = "ml.g5.24xlarge",
    ML_G5_2XLARGE = "ml.g5.2xlarge",
    ML_G5_48XLARGE = "ml.g5.48xlarge",
    ML_G5_4XLARGE = "ml.g5.4xlarge",
    ML_G5_8XLARGE = "ml.g5.8xlarge",
    ML_G5_XLARGE = "ml.g5.xlarge",
    ML_M4_10XLARGE = "ml.m4.10xlarge",
    ML_M4_16XLARGE = "ml.m4.16xlarge",
    ML_M4_2XLARGE = "ml.m4.2xlarge",
    ML_M4_4XLARGE = "ml.m4.4xlarge",
    ML_M4_XLARGE = "ml.m4.xlarge",
    ML_M5_12XLARGE = "ml.m5.12xlarge",
    ML_M5_24XLARGE = "ml.m5.24xlarge",
    ML_M5_2XLARGE = "ml.m5.2xlarge",
    ML_M5_4XLARGE = "ml.m5.4xlarge",
    ML_M5_LARGE = "ml.m5.large",
    ML_M5_XLARGE = "ml.m5.xlarge",
    ML_P2_16XLARGE = "ml.p2.16xlarge",
    ML_P2_8XLARGE = "ml.p2.8xlarge",
    ML_P2_XLARGE = "ml.p2.xlarge",
    ML_P3DN_24XLARGE = "ml.p3dn.24xlarge",
    ML_P3_16XLARGE = "ml.p3.16xlarge",
    ML_P3_2XLARGE = "ml.p3.2xlarge",
    ML_P3_8XLARGE = "ml.p3.8xlarge",
    ML_P4D_24XLARGE = "ml.p4d.24xlarge"
}

export interface ResourceConfig {
    
    InstanceType: TrainingInstanceType | string | undefined;
    
    InstanceCount: number | undefined;
    
    VolumeSizeInGB: number | undefined;
    
    VolumeKmsKeyId?: string;
}
export declare namespace ResourceConfig {
    
    const filterSensitiveLog: (obj: ResourceConfig) => any;
}

export interface StoppingCondition {
    
    MaxRuntimeInSeconds?: number;
    
    MaxWaitTimeInSeconds?: number;
}
export declare namespace StoppingCondition {
    
    const filterSensitiveLog: (obj: StoppingCondition) => any;
}

export interface TrainingJobDefinition {
    
    TrainingInputMode: TrainingInputMode | string | undefined;
    
    HyperParameters?: {
        [key: string]: string;
    };
    
    InputDataConfig: Channel[] | undefined;
    
    OutputDataConfig: OutputDataConfig | undefined;
    
    ResourceConfig: ResourceConfig | undefined;
    
    StoppingCondition: StoppingCondition | undefined;
}
export declare namespace TrainingJobDefinition {
    
    const filterSensitiveLog: (obj: TrainingJobDefinition) => any;
}
export declare enum BatchStrategy {
    MULTI_RECORD = "MultiRecord",
    SINGLE_RECORD = "SingleRecord"
}

export interface TransformS3DataSource {
    
    S3DataType: S3DataType | string | undefined;
    
    S3Uri: string | undefined;
}
export declare namespace TransformS3DataSource {
    
    const filterSensitiveLog: (obj: TransformS3DataSource) => any;
}

export interface TransformDataSource {
    
    S3DataSource: TransformS3DataSource | undefined;
}
export declare namespace TransformDataSource {
    
    const filterSensitiveLog: (obj: TransformDataSource) => any;
}
export declare enum SplitType {
    LINE = "Line",
    NONE = "None",
    RECORDIO = "RecordIO",
    TFRECORD = "TFRecord"
}

export interface TransformInput {
    
    DataSource: TransformDataSource | undefined;
    
    ContentType?: string;
    
    CompressionType?: CompressionType | string;
    
    SplitType?: SplitType | string;
}
export declare namespace TransformInput {
    
    const filterSensitiveLog: (obj: TransformInput) => any;
}
export declare enum AssemblyType {
    LINE = "Line",
    NONE = "None"
}

export interface TransformOutput {
    
    S3OutputPath: string | undefined;
    
    Accept?: string;
    
    AssembleWith?: AssemblyType | string;
    
    KmsKeyId?: string;
}
export declare namespace TransformOutput {
    
    const filterSensitiveLog: (obj: TransformOutput) => any;
}

export interface TransformResources {
    
    InstanceType: TransformInstanceType | string | undefined;
    
    InstanceCount: number | undefined;
    
    VolumeKmsKeyId?: string;
}
export declare namespace TransformResources {
    
    const filterSensitiveLog: (obj: TransformResources) => any;
}

export interface TransformJobDefinition {
    
    MaxConcurrentTransforms?: number;
    
    MaxPayloadInMB?: number;
    
    BatchStrategy?: BatchStrategy | string;
    
    Environment?: {
        [key: string]: string;
    };
    
    TransformInput: TransformInput | undefined;
    
    TransformOutput: TransformOutput | undefined;
    
    TransformResources: TransformResources | undefined;
}
export declare namespace TransformJobDefinition {
    
    const filterSensitiveLog: (obj: TransformJobDefinition) => any;
}

export interface AlgorithmValidationProfile {
    
    ProfileName: string | undefined;
    
    TrainingJobDefinition: TrainingJobDefinition | undefined;
    
    TransformJobDefinition?: TransformJobDefinition;
}
export declare namespace AlgorithmValidationProfile {
    
    const filterSensitiveLog: (obj: AlgorithmValidationProfile) => any;
}

export interface AlgorithmValidationSpecification {
    
    ValidationRole: string | undefined;
    
    ValidationProfiles: AlgorithmValidationProfile[] | undefined;
}
export declare namespace AlgorithmValidationSpecification {
    
    const filterSensitiveLog: (obj: AlgorithmValidationSpecification) => any;
}

export interface AnnotationConsolidationConfig {
    
    AnnotationConsolidationLambdaArn: string | undefined;
}
export declare namespace AnnotationConsolidationConfig {
    
    const filterSensitiveLog: (obj: AnnotationConsolidationConfig) => any;
}
export declare enum AppType {
    JupyterServer = "JupyterServer",
    KernelGateway = "KernelGateway",
    RSessionGateway = "RSessionGateway",
    RStudioServerPro = "RStudioServerPro",
    TensorBoard = "TensorBoard"
}
export declare enum AppStatus {
    Deleted = "Deleted",
    Deleting = "Deleting",
    Failed = "Failed",
    InService = "InService",
    Pending = "Pending"
}

export interface AppDetails {
    
    DomainId?: string;
    
    UserProfileName?: string;
    
    AppType?: AppType | string;
    
    AppName?: string;
    
    Status?: AppStatus | string;
    
    CreationTime?: Date;
}
export declare namespace AppDetails {
    
    const filterSensitiveLog: (obj: AppDetails) => any;
}

export interface FileSystemConfig {
    
    MountPath?: string;
    
    DefaultUid?: number;
    
    DefaultGid?: number;
}
export declare namespace FileSystemConfig {
    
    const filterSensitiveLog: (obj: FileSystemConfig) => any;
}

export interface KernelSpec {
    
    Name: string | undefined;
    
    DisplayName?: string;
}
export declare namespace KernelSpec {
    
    const filterSensitiveLog: (obj: KernelSpec) => any;
}

export interface KernelGatewayImageConfig {
    
    KernelSpecs: KernelSpec[] | undefined;
    
    FileSystemConfig?: FileSystemConfig;
}
export declare namespace KernelGatewayImageConfig {
    
    const filterSensitiveLog: (obj: KernelGatewayImageConfig) => any;
}

export interface AppImageConfigDetails {
    
    AppImageConfigArn?: string;
    
    AppImageConfigName?: string;
    
    CreationTime?: Date;
    
    LastModifiedTime?: Date;
    
    KernelGatewayImageConfig?: KernelGatewayImageConfig;
}
export declare namespace AppImageConfigDetails {
    
    const filterSensitiveLog: (obj: AppImageConfigDetails) => any;
}
export declare enum AppImageConfigSortKey {
    CreationTime = "CreationTime",
    LastModifiedTime = "LastModifiedTime",
    Name = "Name"
}
export declare enum AppInstanceType {
    ML_C5_12XLARGE = "ml.c5.12xlarge",
    ML_C5_18XLARGE = "ml.c5.18xlarge",
    ML_C5_24XLARGE = "ml.c5.24xlarge",
    ML_C5_2XLARGE = "ml.c5.2xlarge",
    ML_C5_4XLARGE = "ml.c5.4xlarge",
    ML_C5_9XLARGE = "ml.c5.9xlarge",
    ML_C5_LARGE = "ml.c5.large",
    ML_C5_XLARGE = "ml.c5.xlarge",
    ML_G4DN_12XLARGE = "ml.g4dn.12xlarge",
    ML_G4DN_16XLARGE = "ml.g4dn.16xlarge",
    ML_G4DN_2XLARGE = "ml.g4dn.2xlarge",
    ML_G4DN_4XLARGE = "ml.g4dn.4xlarge",
    ML_G4DN_8XLARGE = "ml.g4dn.8xlarge",
    ML_G4DN_XLARGE = "ml.g4dn.xlarge",
    ML_M5D_12XLARGE = "ml.m5d.12xlarge",
    ML_M5D_16XLARGE = "ml.m5d.16xlarge",
    ML_M5D_24XLARGE = "ml.m5d.24xlarge",
    ML_M5D_2XLARGE = "ml.m5d.2xlarge",
    ML_M5D_4XLARGE = "ml.m5d.4xlarge",
    ML_M5D_8XLARGE = "ml.m5d.8xlarge",
    ML_M5D_LARGE = "ml.m5d.large",
    ML_M5D_XLARGE = "ml.m5d.xlarge",
    ML_M5_12XLARGE = "ml.m5.12xlarge",
    ML_M5_16XLARGE = "ml.m5.16xlarge",
    ML_M5_24XLARGE = "ml.m5.24xlarge",
    ML_M5_2XLARGE = "ml.m5.2xlarge",
    ML_M5_4XLARGE = "ml.m5.4xlarge",
    ML_M5_8XLARGE = "ml.m5.8xlarge",
    ML_M5_LARGE = "ml.m5.large",
    ML_M5_XLARGE = "ml.m5.xlarge",
    ML_P3DN_24XLARGE = "ml.p3dn.24xlarge",
    ML_P3_16XLARGE = "ml.p3.16xlarge",
    ML_P3_2XLARGE = "ml.p3.2xlarge",
    ML_P3_8XLARGE = "ml.p3.8xlarge",
    ML_R5_12XLARGE = "ml.r5.12xlarge",
    ML_R5_16XLARGE = "ml.r5.16xlarge",
    ML_R5_24XLARGE = "ml.r5.24xlarge",
    ML_R5_2XLARGE = "ml.r5.2xlarge",
    ML_R5_4XLARGE = "ml.r5.4xlarge",
    ML_R5_8XLARGE = "ml.r5.8xlarge",
    ML_R5_LARGE = "ml.r5.large",
    ML_R5_XLARGE = "ml.r5.xlarge",
    ML_T3_2XLARGE = "ml.t3.2xlarge",
    ML_T3_LARGE = "ml.t3.large",
    ML_T3_MEDIUM = "ml.t3.medium",
    ML_T3_MICRO = "ml.t3.micro",
    ML_T3_SMALL = "ml.t3.small",
    ML_T3_XLARGE = "ml.t3.xlarge",
    SYSTEM = "system"
}
export declare enum AppNetworkAccessType {
    PublicInternetOnly = "PublicInternetOnly",
    VpcOnly = "VpcOnly"
}
export declare enum AppSecurityGroupManagement {
    Customer = "Customer",
    Service = "Service"
}
export declare enum AppSortKey {
    CreationTime = "CreationTime"
}

export interface AppSpecification {
    
    ImageUri: string | undefined;
    
    ContainerEntrypoint?: string[];
    
    ContainerArguments?: string[];
}
export declare namespace AppSpecification {
    
    const filterSensitiveLog: (obj: AppSpecification) => any;
}
export declare enum ArtifactSourceIdType {
    CUSTOM = "Custom",
    MD5_HASH = "MD5Hash",
    S3_ETAG = "S3ETag",
    S3_VERSION = "S3Version"
}

export interface ArtifactSourceType {
    
    SourceIdType: ArtifactSourceIdType | string | undefined;
    
    Value: string | undefined;
}
export declare namespace ArtifactSourceType {
    
    const filterSensitiveLog: (obj: ArtifactSourceType) => any;
}

export interface ArtifactSource {
    
    SourceUri: string | undefined;
    
    SourceTypes?: ArtifactSourceType[];
}
export declare namespace ArtifactSource {
    
    const filterSensitiveLog: (obj: ArtifactSource) => any;
}

export interface ArtifactSummary {
    
    ArtifactArn?: string;
    
    ArtifactName?: string;
    
    Source?: ArtifactSource;
    
    ArtifactType?: string;
    
    CreationTime?: Date;
    
    LastModifiedTime?: Date;
}
export declare namespace ArtifactSummary {
    
    const filterSensitiveLog: (obj: ArtifactSummary) => any;
}
export interface AssociateTrialComponentRequest {
    
    TrialComponentName: string | undefined;
    
    TrialName: string | undefined;
}
export declare namespace AssociateTrialComponentRequest {
    
    const filterSensitiveLog: (obj: AssociateTrialComponentRequest) => any;
}
export interface AssociateTrialComponentResponse {
    
    TrialComponentArn?: string;
    
    TrialArn?: string;
}
export declare namespace AssociateTrialComponentResponse {
    
    const filterSensitiveLog: (obj: AssociateTrialComponentResponse) => any;
}

export interface UserContext {
    
    UserProfileArn?: string;
    
    UserProfileName?: string;
    
    DomainId?: string;
}
export declare namespace UserContext {
    
    const filterSensitiveLog: (obj: UserContext) => any;
}

export interface AssociationSummary {
    
    SourceArn?: string;
    
    DestinationArn?: string;
    
    SourceType?: string;
    
    DestinationType?: string;
    
    AssociationType?: AssociationEdgeType | string;
    
    SourceName?: string;
    
    DestinationName?: string;
    
    CreationTime?: Date;
    
    CreatedBy?: UserContext;
}
export declare namespace AssociationSummary {
    
    const filterSensitiveLog: (obj: AssociationSummary) => any;
}

export interface AsyncInferenceClientConfig {
    
    MaxConcurrentInvocationsPerInstance?: number;
}
export declare namespace AsyncInferenceClientConfig {
    
    const filterSensitiveLog: (obj: AsyncInferenceClientConfig) => any;
}

export interface AsyncInferenceNotificationConfig {
    
    SuccessTopic?: string;
    
    ErrorTopic?: string;
}
export declare namespace AsyncInferenceNotificationConfig {
    
    const filterSensitiveLog: (obj: AsyncInferenceNotificationConfig) => any;
}

export interface AsyncInferenceOutputConfig {
    
    KmsKeyId?: string;
    
    S3OutputPath: string | undefined;
    
    NotificationConfig?: AsyncInferenceNotificationConfig;
}
export declare namespace AsyncInferenceOutputConfig {
    
    const filterSensitiveLog: (obj: AsyncInferenceOutputConfig) => any;
}

export interface AsyncInferenceConfig {
    
    ClientConfig?: AsyncInferenceClientConfig;
    
    OutputConfig: AsyncInferenceOutputConfig | undefined;
}
export declare namespace AsyncInferenceConfig {
    
    const filterSensitiveLog: (obj: AsyncInferenceConfig) => any;
}
export declare enum AthenaResultCompressionType {
    GZIP = "GZIP",
    SNAPPY = "SNAPPY",
    ZLIB = "ZLIB"
}
export declare enum AthenaResultFormat {
    AVRO = "AVRO",
    JSON = "JSON",
    ORC = "ORC",
    PARQUET = "PARQUET",
    TEXTFILE = "TEXTFILE"
}

export interface AthenaDatasetDefinition {
    
    Catalog: string | undefined;
    
    Database: string | undefined;
    
    QueryString: string | undefined;
    
    WorkGroup?: string;
    
    OutputS3Uri: string | undefined;
    
    KmsKeyId?: string;
    
    OutputFormat: AthenaResultFormat | string | undefined;
    
    OutputCompression?: AthenaResultCompressionType | string;
}
export declare namespace AthenaDatasetDefinition {
    
    const filterSensitiveLog: (obj: AthenaDatasetDefinition) => any;
}
export declare enum AuthMode {
    IAM = "IAM",
    SSO = "SSO"
}

export interface CandidateArtifactLocations {
    
    Explainability: string | undefined;
    
    ModelInsights?: string;
}
export declare namespace CandidateArtifactLocations {
    
    const filterSensitiveLog: (obj: CandidateArtifactLocations) => any;
}
export declare enum AutoMLMetricEnum {
    ACCURACY = "Accuracy",
    AUC = "AUC",
    F1 = "F1",
    F1_MACRO = "F1macro",
    MSE = "MSE"
}
export declare enum MetricSetSource {
    TEST = "Test",
    TRAIN = "Train",
    VALIDATION = "Validation"
}

export interface MetricDatum {
    
    MetricName?: AutoMLMetricEnum | string;
    
    Value?: number;
    
    Set?: MetricSetSource | string;
}
export declare namespace MetricDatum {
    
    const filterSensitiveLog: (obj: MetricDatum) => any;
}

export interface CandidateProperties {
    
    CandidateArtifactLocations?: CandidateArtifactLocations;
    
    CandidateMetrics?: MetricDatum[];
}
export declare namespace CandidateProperties {
    
    const filterSensitiveLog: (obj: CandidateProperties) => any;
}
export declare enum CandidateStatus {
    COMPLETED = "Completed",
    FAILED = "Failed",
    IN_PROGRESS = "InProgress",
    STOPPED = "Stopped",
    STOPPING = "Stopping"
}
export declare enum CandidateStepType {
    PROCESSING = "AWS::SageMaker::ProcessingJob",
    TRAINING = "AWS::SageMaker::TrainingJob",
    TRANSFORM = "AWS::SageMaker::TransformJob"
}

export interface AutoMLCandidateStep {
    
    CandidateStepType: CandidateStepType | string | undefined;
    
    CandidateStepArn: string | undefined;
    
    CandidateStepName: string | undefined;
}
export declare namespace AutoMLCandidateStep {
    
    const filterSensitiveLog: (obj: AutoMLCandidateStep) => any;
}
export declare enum AutoMLJobObjectiveType {
    MAXIMIZE = "Maximize",
    MINIMIZE = "Minimize"
}

export interface FinalAutoMLJobObjectiveMetric {
    
    Type?: AutoMLJobObjectiveType | string;
    
    MetricName: AutoMLMetricEnum | string | undefined;
    
    Value: number | undefined;
}
export declare namespace FinalAutoMLJobObjectiveMetric {
    
    const filterSensitiveLog: (obj: FinalAutoMLJobObjectiveMetric) => any;
}

export interface AutoMLContainerDefinition {
    
    Image: string | undefined;
    
    ModelDataUrl: string | undefined;
    
    Environment?: {
        [key: string]: string;
    };
}
export declare namespace AutoMLContainerDefinition {
    
    const filterSensitiveLog: (obj: AutoMLContainerDefinition) => any;
}
export declare enum ObjectiveStatus {
    Failed = "Failed",
    Pending = "Pending",
    Succeeded = "Succeeded"
}

export interface AutoMLCandidate {
    
    CandidateName: string | undefined;
    
    FinalAutoMLJobObjectiveMetric?: FinalAutoMLJobObjectiveMetric;
    
    ObjectiveStatus: ObjectiveStatus | string | undefined;
    
    CandidateSteps: AutoMLCandidateStep[] | undefined;
    
    CandidateStatus: CandidateStatus | string | undefined;
    
    InferenceContainers?: AutoMLContainerDefinition[];
    
    CreationTime: Date | undefined;
    
    EndTime?: Date;
    
    LastModifiedTime: Date | undefined;
    
    FailureReason?: string;
    
    CandidateProperties?: CandidateProperties;
}
export declare namespace AutoMLCandidate {
    
    const filterSensitiveLog: (obj: AutoMLCandidate) => any;
}
export declare enum AutoMLS3DataType {
    MANIFEST_FILE = "ManifestFile",
    S3_PREFIX = "S3Prefix"
}

export interface AutoMLS3DataSource {
    
    S3DataType: AutoMLS3DataType | string | undefined;
    
    S3Uri: string | undefined;
}
export declare namespace AutoMLS3DataSource {
    
    const filterSensitiveLog: (obj: AutoMLS3DataSource) => any;
}

export interface AutoMLDataSource {
    
    S3DataSource: AutoMLS3DataSource | undefined;
}
export declare namespace AutoMLDataSource {
    
    const filterSensitiveLog: (obj: AutoMLDataSource) => any;
}

export interface AutoMLChannel {
    
    DataSource: AutoMLDataSource | undefined;
    
    CompressionType?: CompressionType | string;
    
    TargetAttributeName: string | undefined;
    
    ContentType?: string;
}
export declare namespace AutoMLChannel {
    
    const filterSensitiveLog: (obj: AutoMLChannel) => any;
}

export interface AutoMLJobArtifacts {
    
    CandidateDefinitionNotebookLocation?: string;
    
    DataExplorationNotebookLocation?: string;
}
export declare namespace AutoMLJobArtifacts {
    
    const filterSensitiveLog: (obj: AutoMLJobArtifacts) => any;
}

export interface AutoMLJobCompletionCriteria {
    
    MaxCandidates?: number;
    
    MaxRuntimePerTrainingJobInSeconds?: number;
    
    MaxAutoMLJobRuntimeInSeconds?: number;
}
export declare namespace AutoMLJobCompletionCriteria {
    
    const filterSensitiveLog: (obj: AutoMLJobCompletionCriteria) => any;
}

export interface VpcConfig {
    
    SecurityGroupIds: string[] | undefined;
    
    Subnets: string[] | undefined;
}
export declare namespace VpcConfig {
    
    const filterSensitiveLog: (obj: VpcConfig) => any;
}

export interface AutoMLSecurityConfig {
    
    VolumeKmsKeyId?: string;
    
    EnableInterContainerTrafficEncryption?: boolean;
    
    VpcConfig?: VpcConfig;
}
export declare namespace AutoMLSecurityConfig {
    
    const filterSensitiveLog: (obj: AutoMLSecurityConfig) => any;
}

export interface AutoMLJobConfig {
    
    CompletionCriteria?: AutoMLJobCompletionCriteria;
    
    SecurityConfig?: AutoMLSecurityConfig;
}
export declare namespace AutoMLJobConfig {
    
    const filterSensitiveLog: (obj: AutoMLJobConfig) => any;
}

export interface AutoMLJobObjective {
    
    MetricName: AutoMLMetricEnum | string | undefined;
}
export declare namespace AutoMLJobObjective {
    
    const filterSensitiveLog: (obj: AutoMLJobObjective) => any;
}
export declare enum AutoMLJobSecondaryStatus {
    ANALYZING_DATA = "AnalyzingData",
    CANDIDATE_DEFINITIONS_GENERATED = "CandidateDefinitionsGenerated",
    COMPLETED = "Completed",
    DEPLOYING_MODEL = "DeployingModel",
    EXPLAINABILITY_ERROR = "ExplainabilityError",
    FAILED = "Failed",
    FEATURE_ENGINEERING = "FeatureEngineering",
    GENERATING_EXPLAINABILITY_REPORT = "GeneratingExplainabilityReport",
    GENERATING_MODEL_INSIGHTS_REPORT = "GeneratingModelInsightsReport",
    MAX_AUTO_ML_JOB_RUNTIME_REACHED = "MaxAutoMLJobRuntimeReached",
    MAX_CANDIDATES_REACHED = "MaxCandidatesReached",
    MODEL_DEPLOYMENT_ERROR = "ModelDeploymentError",
    MODEL_INSIGHTS_ERROR = "ModelInsightsError",
    MODEL_TUNING = "ModelTuning",
    STARTING = "Starting",
    STOPPED = "Stopped",
    STOPPING = "Stopping"
}
export declare enum AutoMLJobStatus {
    COMPLETED = "Completed",
    FAILED = "Failed",
    IN_PROGRESS = "InProgress",
    STOPPED = "Stopped",
    STOPPING = "Stopping"
}

export interface AutoMLPartialFailureReason {
    
    PartialFailureMessage?: string;
}
export declare namespace AutoMLPartialFailureReason {
    
    const filterSensitiveLog: (obj: AutoMLPartialFailureReason) => any;
}

export interface AutoMLJobSummary {
    
    AutoMLJobName: string | undefined;
    
    AutoMLJobArn: string | undefined;
    
    AutoMLJobStatus: AutoMLJobStatus | string | undefined;
    
    AutoMLJobSecondaryStatus: AutoMLJobSecondaryStatus | string | undefined;
    
    CreationTime: Date | undefined;
    
    EndTime?: Date;
    
    LastModifiedTime: Date | undefined;
    
    FailureReason?: string;
    
    PartialFailureReasons?: AutoMLPartialFailureReason[];
}
export declare namespace AutoMLJobSummary {
    
    const filterSensitiveLog: (obj: AutoMLJobSummary) => any;
}

export interface AutoMLOutputDataConfig {
    
    KmsKeyId?: string;
    
    S3OutputPath: string | undefined;
}
export declare namespace AutoMLOutputDataConfig {
    
    const filterSensitiveLog: (obj: AutoMLOutputDataConfig) => any;
}
export declare enum AutoMLSortBy {
    CREATION_TIME = "CreationTime",
    NAME = "Name",
    STATUS = "Status"
}
export declare enum AutoMLSortOrder {
    ASCENDING = "Ascending",
    DESCENDING = "Descending"
}

export interface AutoRollbackConfig {
    
    Alarms?: Alarm[];
}
export declare namespace AutoRollbackConfig {
    
    const filterSensitiveLog: (obj: AutoRollbackConfig) => any;
}
export declare enum AwsManagedHumanLoopRequestSource {
    REKOGNITION_DETECT_MODERATION_LABELS_IMAGE_V3 = "AWS/Rekognition/DetectModerationLabels/Image/V3",
    TEXTRACT_ANALYZE_DOCUMENT_FORMS_V1 = "AWS/Textract/AnalyzeDocument/Forms/V1"
}
export interface BatchDescribeModelPackageInput {
    
    ModelPackageArnList: string[] | undefined;
}
export declare namespace BatchDescribeModelPackageInput {
    
    const filterSensitiveLog: (obj: BatchDescribeModelPackageInput) => any;
}

export interface BatchDescribeModelPackageError {
    
    ErrorCode: string | undefined;
    
    ErrorResponse: string | undefined;
}
export declare namespace BatchDescribeModelPackageError {
    
    const filterSensitiveLog: (obj: BatchDescribeModelPackageError) => any;
}

export interface InferenceSpecification {
    
    Containers: ModelPackageContainerDefinition[] | undefined;
    
    SupportedTransformInstanceTypes?: (TransformInstanceType | string)[];
    
    SupportedRealtimeInferenceInstanceTypes?: (ProductionVariantInstanceType | string)[];
    
    SupportedContentTypes: string[] | undefined;
    
    SupportedResponseMIMETypes: string[] | undefined;
}
export declare namespace InferenceSpecification {
    
    const filterSensitiveLog: (obj: InferenceSpecification) => any;
}
export declare enum ModelApprovalStatus {
    APPROVED = "Approved",
    PENDING_MANUAL_APPROVAL = "PendingManualApproval",
    REJECTED = "Rejected"
}
export declare enum ModelPackageStatus {
    COMPLETED = "Completed",
    DELETING = "Deleting",
    FAILED = "Failed",
    IN_PROGRESS = "InProgress",
    PENDING = "Pending"
}

export interface BatchDescribeModelPackageSummary {
    
    ModelPackageGroupName: string | undefined;
    
    ModelPackageVersion?: number;
    
    ModelPackageArn: string | undefined;
    
    ModelPackageDescription?: string;
    
    CreationTime: Date | undefined;
    
    InferenceSpecification: InferenceSpecification | undefined;
    
    ModelPackageStatus: ModelPackageStatus | string | undefined;
    
    ModelApprovalStatus?: ModelApprovalStatus | string;
}
export declare namespace BatchDescribeModelPackageSummary {
    
    const filterSensitiveLog: (obj: BatchDescribeModelPackageSummary) => any;
}
export interface BatchDescribeModelPackageOutput {
    
    ModelPackageSummaries?: {
        [key: string]: BatchDescribeModelPackageSummary;
    };
    
    BatchDescribeModelPackageErrorMap?: {
        [key: string]: BatchDescribeModelPackageError;
    };
}
export declare namespace BatchDescribeModelPackageOutput {
    
    const filterSensitiveLog: (obj: BatchDescribeModelPackageOutput) => any;
}

export interface MetricsSource {
    
    ContentType: string | undefined;
    
    ContentDigest?: string;
    
    S3Uri: string | undefined;
}
export declare namespace MetricsSource {
    
    const filterSensitiveLog: (obj: MetricsSource) => any;
}

export interface Bias {
    
    Report?: MetricsSource;
    
    PreTrainingReport?: MetricsSource;
    
    PostTrainingReport?: MetricsSource;
}
export declare namespace Bias {
    
    const filterSensitiveLog: (obj: Bias) => any;
}
export declare enum CapacitySizeType {
    CAPACITY_PERCENT = "CAPACITY_PERCENT",
    INSTANCE_COUNT = "INSTANCE_COUNT"
}

export interface CapacitySize {
    
    Type: CapacitySizeType | string | undefined;
    
    Value: number | undefined;
}
export declare namespace CapacitySize {
    
    const filterSensitiveLog: (obj: CapacitySize) => any;
}
export declare enum TrafficRoutingConfigType {
    ALL_AT_ONCE = "ALL_AT_ONCE",
    CANARY = "CANARY",
    LINEAR = "LINEAR"
}

export interface TrafficRoutingConfig {
    
    Type: TrafficRoutingConfigType | string | undefined;
    
    WaitIntervalInSeconds: number | undefined;
    
    CanarySize?: CapacitySize;
    
    LinearStepSize?: CapacitySize;
}
export declare namespace TrafficRoutingConfig {
    
    const filterSensitiveLog: (obj: TrafficRoutingConfig) => any;
}

export interface BlueGreenUpdatePolicy {
    
    TrafficRoutingConfiguration: TrafficRoutingConfig | undefined;
    
    TerminationWaitInSeconds?: number;
    
    MaximumExecutionTimeoutInSeconds?: number;
}
export declare namespace BlueGreenUpdatePolicy {
    
    const filterSensitiveLog: (obj: BlueGreenUpdatePolicy) => any;
}
export declare enum BooleanOperator {
    AND = "And",
    OR = "Or"
}

export interface CacheHitResult {
    
    SourcePipelineExecutionArn?: string;
}
export declare namespace CacheHitResult {
    
    const filterSensitiveLog: (obj: CacheHitResult) => any;
}

export interface OutputParameter {
    
    Name: string | undefined;
    
    Value: string | undefined;
}
export declare namespace OutputParameter {
    
    const filterSensitiveLog: (obj: OutputParameter) => any;
}

export interface CallbackStepMetadata {
    
    CallbackToken?: string;
    
    SqsQueueUrl?: string;
    
    OutputParameters?: OutputParameter[];
}
export declare namespace CallbackStepMetadata {
    
    const filterSensitiveLog: (obj: CallbackStepMetadata) => any;
}
export declare enum CandidateSortBy {
    CreationTime = "CreationTime",
    FinalObjectiveMetricValue = "FinalObjectiveMetricValue",
    Status = "Status"
}

export interface CaptureContentTypeHeader {
    
    CsvContentTypes?: string[];
    
    JsonContentTypes?: string[];
}
export declare namespace CaptureContentTypeHeader {
    
    const filterSensitiveLog: (obj: CaptureContentTypeHeader) => any;
}
export declare enum CaptureMode {
    INPUT = "Input",
    OUTPUT = "Output"
}

export interface CaptureOption {
    
    CaptureMode: CaptureMode | string | undefined;
}
export declare namespace CaptureOption {
    
    const filterSensitiveLog: (obj: CaptureOption) => any;
}
export declare enum CaptureStatus {
    STARTED = "Started",
    STOPPED = "Stopped"
}

export interface CategoricalParameter {
    
    Name: string | undefined;
    
    Value: string[] | undefined;
}
export declare namespace CategoricalParameter {
    
    const filterSensitiveLog: (obj: CategoricalParameter) => any;
}

export interface CategoricalParameterRange {
    
    Name: string | undefined;
    
    Values: string[] | undefined;
}
export declare namespace CategoricalParameterRange {
    
    const filterSensitiveLog: (obj: CategoricalParameterRange) => any;
}

export interface CategoricalParameterRangeSpecification {
    
    Values: string[] | undefined;
}
export declare namespace CategoricalParameterRangeSpecification {
    
    const filterSensitiveLog: (obj: CategoricalParameterRangeSpecification) => any;
}

export interface ChannelSpecification {
    
    Name: string | undefined;
    
    Description?: string;
    
    IsRequired?: boolean;
    
    SupportedContentTypes: string[] | undefined;
    
    SupportedCompressionTypes?: (CompressionType | string)[];
    
    SupportedInputModes: (TrainingInputMode | string)[] | undefined;
}
export declare namespace ChannelSpecification {
    
    const filterSensitiveLog: (obj: ChannelSpecification) => any;
}

export interface CheckpointConfig {
    
    S3Uri: string | undefined;
    
    LocalPath?: string;
}
export declare namespace CheckpointConfig {
    
    const filterSensitiveLog: (obj: CheckpointConfig) => any;
}

export interface ClarifyCheckStepMetadata {
    
    CheckType?: string;
    
    BaselineUsedForDriftCheckConstraints?: string;
    
    CalculatedBaselineConstraints?: string;
    
    ModelPackageGroupName?: string;
    
    ViolationReport?: string;
    
    CheckJobArn?: string;
    
    SkipCheck?: boolean;
    
    RegisterNewBaseline?: boolean;
}
export declare namespace ClarifyCheckStepMetadata {
    
    const filterSensitiveLog: (obj: ClarifyCheckStepMetadata) => any;
}
export declare enum CodeRepositorySortBy {
    CREATION_TIME = "CreationTime",
    LAST_MODIFIED_TIME = "LastModifiedTime",
    NAME = "Name"
}
export declare enum CodeRepositorySortOrder {
    ASCENDING = "Ascending",
    DESCENDING = "Descending"
}

export interface GitConfig {
    
    RepositoryUrl: string | undefined;
    
    Branch?: string;
    
    SecretArn?: string;
}
export declare namespace GitConfig {
    
    const filterSensitiveLog: (obj: GitConfig) => any;
}

export interface CodeRepositorySummary {
    
    CodeRepositoryName: string | undefined;
    
    CodeRepositoryArn: string | undefined;
    
    CreationTime: Date | undefined;
    
    LastModifiedTime: Date | undefined;
    
    GitConfig?: GitConfig;
}
export declare namespace CodeRepositorySummary {
    
    const filterSensitiveLog: (obj: CodeRepositorySummary) => any;
}

export interface CognitoConfig {
    
    UserPool: string | undefined;
    
    ClientId: string | undefined;
}
export declare namespace CognitoConfig {
    
    const filterSensitiveLog: (obj: CognitoConfig) => any;
}

export interface CognitoMemberDefinition {
    
    UserPool: string | undefined;
    
    UserGroup: string | undefined;
    
    ClientId: string | undefined;
}
export declare namespace CognitoMemberDefinition {
    
    const filterSensitiveLog: (obj: CognitoMemberDefinition) => any;
}

export interface CollectionConfiguration {
    
    CollectionName?: string;
    
    CollectionParameters?: {
        [key: string]: string;
    };
}
export declare namespace CollectionConfiguration {
    
    const filterSensitiveLog: (obj: CollectionConfiguration) => any;
}
export declare enum CompilationJobStatus {
    COMPLETED = "COMPLETED",
    FAILED = "FAILED",
    INPROGRESS = "INPROGRESS",
    STARTING = "STARTING",
    STOPPED = "STOPPED",
    STOPPING = "STOPPING"
}
export declare enum TargetDevice {
    AISAGE = "aisage",
    AMBA_CV2 = "amba_cv2",
    AMBA_CV22 = "amba_cv22",
    AMBA_CV25 = "amba_cv25",
    COREML = "coreml",
    DEEPLENS = "deeplens",
    IMX8MPLUS = "imx8mplus",
    IMX8QM = "imx8qm",
    JACINTO_TDA4VM = "jacinto_tda4vm",
    JETSON_NANO = "jetson_nano",
    JETSON_TX1 = "jetson_tx1",
    JETSON_TX2 = "jetson_tx2",
    JETSON_XAVIER = "jetson_xavier",
    LAMBDA = "lambda",
    ML_C4 = "ml_c4",
    ML_C5 = "ml_c5",
    ML_EIA2 = "ml_eia2",
    ML_G4DN = "ml_g4dn",
    ML_INF1 = "ml_inf1",
    ML_M4 = "ml_m4",
    ML_M5 = "ml_m5",
    ML_P2 = "ml_p2",
    ML_P3 = "ml_p3",
    QCS603 = "qcs603",
    QCS605 = "qcs605",
    RASP3B = "rasp3b",
    RK3288 = "rk3288",
    RK3399 = "rk3399",
    SBE_C = "sbe_c",
    SITARA_AM57X = "sitara_am57x",
    X86_WIN32 = "x86_win32",
    X86_WIN64 = "x86_win64"
}
export declare enum TargetPlatformAccelerator {
    INTEL_GRAPHICS = "INTEL_GRAPHICS",
    MALI = "MALI",
    NNA = "NNA",
    NVIDIA = "NVIDIA"
}
export declare enum TargetPlatformArch {
    ARM64 = "ARM64",
    ARM_EABI = "ARM_EABI",
    ARM_EABIHF = "ARM_EABIHF",
    X86 = "X86",
    X86_64 = "X86_64"
}
export declare enum TargetPlatformOs {
    ANDROID = "ANDROID",
    LINUX = "LINUX"
}

export interface CompilationJobSummary {
    
    CompilationJobName: string | undefined;
    
    CompilationJobArn: string | undefined;
    
    CreationTime: Date | undefined;
    
    CompilationStartTime?: Date;
    
    CompilationEndTime?: Date;
    
    CompilationTargetDevice?: TargetDevice | string;
    
    CompilationTargetPlatformOs?: TargetPlatformOs | string;
    
    CompilationTargetPlatformArch?: TargetPlatformArch | string;
    
    CompilationTargetPlatformAccelerator?: TargetPlatformAccelerator | string;
    
    LastModifiedTime?: Date;
    
    CompilationJobStatus: CompilationJobStatus | string | undefined;
}
export declare namespace CompilationJobSummary {
    
    const filterSensitiveLog: (obj: CompilationJobSummary) => any;
}
export declare enum ConditionOutcome {
    FALSE = "False",
    TRUE = "True"
}

export interface ConditionStepMetadata {
    
    Outcome?: ConditionOutcome | string;
}
export declare namespace ConditionStepMetadata {
    
    const filterSensitiveLog: (obj: ConditionStepMetadata) => any;
}

export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export declare enum RepositoryAccessMode {
    PLATFORM = "Platform",
    VPC = "Vpc"
}

export interface RepositoryAuthConfig {
    
    RepositoryCredentialsProviderArn: string | undefined;
}
export declare namespace RepositoryAuthConfig {
    
    const filterSensitiveLog: (obj: RepositoryAuthConfig) => any;
}

export interface ImageConfig {
    
    RepositoryAccessMode: RepositoryAccessMode | string | undefined;
    
    RepositoryAuthConfig?: RepositoryAuthConfig;
}
export declare namespace ImageConfig {
    
    const filterSensitiveLog: (obj: ImageConfig) => any;
}
export declare enum ContainerMode {
    MULTI_MODEL = "MultiModel",
    SINGLE_MODEL = "SingleModel"
}
export declare enum ModelCacheSetting {
    DISABLED = "Disabled",
    ENABLED = "Enabled"
}

export interface MultiModelConfig {
    
    ModelCacheSetting?: ModelCacheSetting | string;
}
export declare namespace MultiModelConfig {
    
    const filterSensitiveLog: (obj: MultiModelConfig) => any;
}

export interface ContainerDefinition {
    
    ContainerHostname?: string;
    
    Image?: string;
    
    ImageConfig?: ImageConfig;
    
    Mode?: ContainerMode | string;
    
    ModelDataUrl?: string;
    
    Environment?: {
        [key: string]: string;
    };
    
    ModelPackageName?: string;
    
    InferenceSpecificationName?: string;
    
    MultiModelConfig?: MultiModelConfig;
}
export declare namespace ContainerDefinition {
    
    const filterSensitiveLog: (obj: ContainerDefinition) => any;
}
export declare enum ContentClassifier {
    FREE_OF_ADULT_CONTENT = "FreeOfAdultContent",
    FREE_OF_PERSONALLY_IDENTIFIABLE_INFORMATION = "FreeOfPersonallyIdentifiableInformation"
}

export interface ContextSource {
    
    SourceUri: string | undefined;
    
    SourceType?: string;
    
    SourceId?: string;
}
export declare namespace ContextSource {
    
    const filterSensitiveLog: (obj: ContextSource) => any;
}

export interface ContextSummary {
    
    ContextArn?: string;
    
    ContextName?: string;
    
    Source?: ContextSource;
    
    ContextType?: string;
    
    CreationTime?: Date;
    
    LastModifiedTime?: Date;
}
export declare namespace ContextSummary {
    
    const filterSensitiveLog: (obj: ContextSummary) => any;
}
export declare enum HyperParameterScalingType {
    AUTO = "Auto",
    LINEAR = "Linear",
    LOGARITHMIC = "Logarithmic",
    REVERSE_LOGARITHMIC = "ReverseLogarithmic"
}

export interface ContinuousParameterRange {
    
    Name: string | undefined;
    
    MinValue: string | undefined;
    
    MaxValue: string | undefined;
    
    ScalingType?: HyperParameterScalingType | string;
}
export declare namespace ContinuousParameterRange {
    
    const filterSensitiveLog: (obj: ContinuousParameterRange) => any;
}

export interface ContinuousParameterRangeSpecification {
    
    MinValue: string | undefined;
    
    MaxValue: string | undefined;
}
export declare namespace ContinuousParameterRangeSpecification {
    
    const filterSensitiveLog: (obj: ContinuousParameterRangeSpecification) => any;
}

export interface MetadataProperties {
    
    CommitId?: string;
    
    Repository?: string;
    
    GeneratedBy?: string;
    
    ProjectId?: string;
}
export declare namespace MetadataProperties {
    
    const filterSensitiveLog: (obj: MetadataProperties) => any;
}
export interface CreateActionRequest {
    
    ActionName: string | undefined;
    
    Source: ActionSource | undefined;
    
    ActionType: string | undefined;
    
    Description?: string;
    
    Status?: ActionStatus | string;
    
    Properties?: {
        [key: string]: string;
    };
    
    MetadataProperties?: MetadataProperties;
    
    Tags?: Tag[];
}
export declare namespace CreateActionRequest {
    
    const filterSensitiveLog: (obj: CreateActionRequest) => any;
}
export interface CreateActionResponse {
    
    ActionArn?: string;
}
export declare namespace CreateActionResponse {
    
    const filterSensitiveLog: (obj: CreateActionResponse) => any;
}

export interface IntegerParameterRangeSpecification {
    
    MinValue: string | undefined;
    
    MaxValue: string | undefined;
}
export declare namespace IntegerParameterRangeSpecification {
    
    const filterSensitiveLog: (obj: IntegerParameterRangeSpecification) => any;
}

export interface ParameterRange {
    
    IntegerParameterRangeSpecification?: IntegerParameterRangeSpecification;
    
    ContinuousParameterRangeSpecification?: ContinuousParameterRangeSpecification;
    
    CategoricalParameterRangeSpecification?: CategoricalParameterRangeSpecification;
}
export declare namespace ParameterRange {
    
    const filterSensitiveLog: (obj: ParameterRange) => any;
}
export declare enum ParameterType {
    CATEGORICAL = "Categorical",
    CONTINUOUS = "Continuous",
    FREE_TEXT = "FreeText",
    INTEGER = "Integer"
}

export interface HyperParameterSpecification {
    
    Name: string | undefined;
    
    Description?: string;
    
    Type: ParameterType | string | undefined;
    
    Range?: ParameterRange;
    
    IsTunable?: boolean;
    
    IsRequired?: boolean;
    
    DefaultValue?: string;
}
export declare namespace HyperParameterSpecification {
    
    const filterSensitiveLog: (obj: HyperParameterSpecification) => any;
}
export declare enum HyperParameterTuningJobObjectiveType {
    MAXIMIZE = "Maximize",
    MINIMIZE = "Minimize"
}

export interface HyperParameterTuningJobObjective {
    
    Type: HyperParameterTuningJobObjectiveType | string | undefined;
    
    MetricName: string | undefined;
}
export declare namespace HyperParameterTuningJobObjective {
    
    const filterSensitiveLog: (obj: HyperParameterTuningJobObjective) => any;
}

export interface TrainingSpecification {
    
    TrainingImage: string | undefined;
    
    TrainingImageDigest?: string;
    
    SupportedHyperParameters?: HyperParameterSpecification[];
    
    SupportedTrainingInstanceTypes: (TrainingInstanceType | string)[] | undefined;
    
    SupportsDistributedTraining?: boolean;
    
    MetricDefinitions?: MetricDefinition[];
    
    TrainingChannels: ChannelSpecification[] | undefined;
    
    SupportedTuningJobObjectiveMetrics?: HyperParameterTuningJobObjective[];
}
export declare namespace TrainingSpecification {
    
    const filterSensitiveLog: (obj: TrainingSpecification) => any;
}
export interface CreateAlgorithmInput {
    
    AlgorithmName: string | undefined;
    
    AlgorithmDescription?: string;
    
    TrainingSpecification: TrainingSpecification | undefined;
    
    InferenceSpecification?: InferenceSpecification;
    
    ValidationSpecification?: AlgorithmValidationSpecification;
    
    CertifyForMarketplace?: boolean;
    
    Tags?: Tag[];
}
export declare namespace CreateAlgorithmInput {
    
    const filterSensitiveLog: (obj: CreateAlgorithmInput) => any;
}
export interface CreateAlgorithmOutput {
    
    AlgorithmArn: string | undefined;
}
export declare namespace CreateAlgorithmOutput {
    
    const filterSensitiveLog: (obj: CreateAlgorithmOutput) => any;
}

export interface ResourceSpec {
    
    SageMakerImageArn?: string;
    
    SageMakerImageVersionArn?: string;
    
    InstanceType?: AppInstanceType | string;
    
    LifecycleConfigArn?: string;
}
export declare namespace ResourceSpec {
    
    const filterSensitiveLog: (obj: ResourceSpec) => any;
}
export interface CreateAppRequest {
    
    DomainId: string | undefined;
    
    UserProfileName: string | undefined;
    
    AppType: AppType | string | undefined;
    
    AppName: string | undefined;
    
    Tags?: Tag[];
    
    ResourceSpec?: ResourceSpec;
}
export declare namespace CreateAppRequest {
    
    const filterSensitiveLog: (obj: CreateAppRequest) => any;
}
export interface CreateAppResponse {
    
    AppArn?: string;
}
export declare namespace CreateAppResponse {
    
    const filterSensitiveLog: (obj: CreateAppResponse) => any;
}

export declare class ResourceInUse extends __BaseException {
    readonly name: "ResourceInUse";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ResourceInUse, __BaseException>);
}
export interface CreateAppImageConfigRequest {
    
    AppImageConfigName: string | undefined;
    
    Tags?: Tag[];
    
    KernelGatewayImageConfig?: KernelGatewayImageConfig;
}
export declare namespace CreateAppImageConfigRequest {
    
    const filterSensitiveLog: (obj: CreateAppImageConfigRequest) => any;
}
export interface CreateAppImageConfigResponse {
    
    AppImageConfigArn?: string;
}
export declare namespace CreateAppImageConfigResponse {
    
    const filterSensitiveLog: (obj: CreateAppImageConfigResponse) => any;
}
export interface CreateArtifactRequest {
    
    ArtifactName?: string;
    
    Source: ArtifactSource | undefined;
    
    ArtifactType: string | undefined;
    
    Properties?: {
        [key: string]: string;
    };
    
    MetadataProperties?: MetadataProperties;
    
    Tags?: Tag[];
}
export declare namespace CreateArtifactRequest {
    
    const filterSensitiveLog: (obj: CreateArtifactRequest) => any;
}
export interface CreateArtifactResponse {
    
    ArtifactArn?: string;
}
export declare namespace CreateArtifactResponse {
    
    const filterSensitiveLog: (obj: CreateArtifactResponse) => any;
}

export interface ModelDeployConfig {
    
    AutoGenerateEndpointName?: boolean;
    
    EndpointName?: string;
}
export declare namespace ModelDeployConfig {
    
    const filterSensitiveLog: (obj: ModelDeployConfig) => any;
}
export declare enum ProblemType {
    BINARY_CLASSIFICATION = "BinaryClassification",
    MULTICLASS_CLASSIFICATION = "MulticlassClassification",
    REGRESSION = "Regression"
}
export interface CreateAutoMLJobRequest {
    
    AutoMLJobName: string | undefined;
    
    InputDataConfig: AutoMLChannel[] | undefined;
    
    OutputDataConfig: AutoMLOutputDataConfig | undefined;
    
    ProblemType?: ProblemType | string;
    
    AutoMLJobObjective?: AutoMLJobObjective;
    
    AutoMLJobConfig?: AutoMLJobConfig;
    
    RoleArn: string | undefined;
    
    GenerateCandidateDefinitionsOnly?: boolean;
    
    Tags?: Tag[];
    
    ModelDeployConfig?: ModelDeployConfig;
}
export declare namespace CreateAutoMLJobRequest {
    
    const filterSensitiveLog: (obj: CreateAutoMLJobRequest) => any;
}
export interface CreateAutoMLJobResponse {
    
    AutoMLJobArn: string | undefined;
}
export declare namespace CreateAutoMLJobResponse {
    
    const filterSensitiveLog: (obj: CreateAutoMLJobResponse) => any;
}
export interface CreateCodeRepositoryInput {
    
    CodeRepositoryName: string | undefined;
    
    GitConfig: GitConfig | undefined;
    
    Tags?: Tag[];
}
export declare namespace CreateCodeRepositoryInput {
    
    const filterSensitiveLog: (obj: CreateCodeRepositoryInput) => any;
}
export interface CreateCodeRepositoryOutput {
    
    CodeRepositoryArn: string | undefined;
}
export declare namespace CreateCodeRepositoryOutput {
    
    const filterSensitiveLog: (obj: CreateCodeRepositoryOutput) => any;
}
export declare enum Framework {
    DARKNET = "DARKNET",
    KERAS = "KERAS",
    MXNET = "MXNET",
    ONNX = "ONNX",
    PYTORCH = "PYTORCH",
    SKLEARN = "SKLEARN",
    TENSORFLOW = "TENSORFLOW",
    TFLITE = "TFLITE",
    XGBOOST = "XGBOOST"
}

export interface InputConfig {
    
    S3Uri: string | undefined;
    
    DataInputConfig: string | undefined;
    
    Framework: Framework | string | undefined;
    
    FrameworkVersion?: string;
}
export declare namespace InputConfig {
    
    const filterSensitiveLog: (obj: InputConfig) => any;
}

export interface TargetPlatform {
    
    Os: TargetPlatformOs | string | undefined;
    
    Arch: TargetPlatformArch | string | undefined;
    
    Accelerator?: TargetPlatformAccelerator | string;
}
export declare namespace TargetPlatform {
    
    const filterSensitiveLog: (obj: TargetPlatform) => any;
}

export interface OutputConfig {
    
    S3OutputLocation: string | undefined;
    
    TargetDevice?: TargetDevice | string;
    
    TargetPlatform?: TargetPlatform;
    
    CompilerOptions?: string;
    
    KmsKeyId?: string;
}
export declare namespace OutputConfig {
    
    const filterSensitiveLog: (obj: OutputConfig) => any;
}

export interface NeoVpcConfig {
    
    SecurityGroupIds: string[] | undefined;
    
    Subnets: string[] | undefined;
}
export declare namespace NeoVpcConfig {
    
    const filterSensitiveLog: (obj: NeoVpcConfig) => any;
}
export interface CreateCompilationJobRequest {
    
    CompilationJobName: string | undefined;
    
    RoleArn: string | undefined;
    
    ModelPackageVersionArn?: string;
    
    InputConfig?: InputConfig;
    
    OutputConfig: OutputConfig | undefined;
    
    VpcConfig?: NeoVpcConfig;
    
    StoppingCondition: StoppingCondition | undefined;
    
    Tags?: Tag[];
}
export declare namespace CreateCompilationJobRequest {
    
    const filterSensitiveLog: (obj: CreateCompilationJobRequest) => any;
}
export interface CreateCompilationJobResponse {
    
    CompilationJobArn: string | undefined;
}
export declare namespace CreateCompilationJobResponse {
    
    const filterSensitiveLog: (obj: CreateCompilationJobResponse) => any;
}
export interface CreateContextRequest {
    
    ContextName: string | undefined;
    
    Source: ContextSource | undefined;
    
    ContextType: string | undefined;
    
    Description?: string;
    
    Properties?: {
        [key: string]: string;
    };
    
    Tags?: Tag[];
}
export declare namespace CreateContextRequest {
    
    const filterSensitiveLog: (obj: CreateContextRequest) => any;
}
export interface CreateContextResponse {
    
    ContextArn?: string;
}
export declare namespace CreateContextResponse {
    
    const filterSensitiveLog: (obj: CreateContextResponse) => any;
}

export interface DataQualityAppSpecification {
    
    ImageUri: string | undefined;
    
    ContainerEntrypoint?: string[];
    
    ContainerArguments?: string[];
    
    RecordPreprocessorSourceUri?: string;
    
    PostAnalyticsProcessorSourceUri?: string;
    
    Environment?: {
        [key: string]: string;
    };
}
export declare namespace DataQualityAppSpecification {
    
    const filterSensitiveLog: (obj: DataQualityAppSpecification) => any;
}

export interface MonitoringConstraintsResource {
    
    S3Uri?: string;
}
export declare namespace MonitoringConstraintsResource {
    
    const filterSensitiveLog: (obj: MonitoringConstraintsResource) => any;
}

export interface MonitoringStatisticsResource {
    
    S3Uri?: string;
}
export declare namespace MonitoringStatisticsResource {
    
    const filterSensitiveLog: (obj: MonitoringStatisticsResource) => any;
}

export interface DataQualityBaselineConfig {
    
    BaseliningJobName?: string;
    
    ConstraintsResource?: MonitoringConstraintsResource;
    
    StatisticsResource?: MonitoringStatisticsResource;
}
export declare namespace DataQualityBaselineConfig {
    
    const filterSensitiveLog: (obj: DataQualityBaselineConfig) => any;
}
export declare enum ProcessingS3DataDistributionType {
    FULLYREPLICATED = "FullyReplicated",
    SHARDEDBYS3KEY = "ShardedByS3Key"
}
export declare enum ProcessingS3InputMode {
    FILE = "File",
    PIPE = "Pipe"
}

export interface EndpointInput {
    
    EndpointName: string | undefined;
    
    LocalPath: string | undefined;
    
    S3InputMode?: ProcessingS3InputMode | string;
    
    S3DataDistributionType?: ProcessingS3DataDistributionType | string;
    
    FeaturesAttribute?: string;
    
    InferenceAttribute?: string;
    
    ProbabilityAttribute?: string;
    
    ProbabilityThresholdAttribute?: number;
    
    StartTimeOffset?: string;
    
    EndTimeOffset?: string;
}
export declare namespace EndpointInput {
    
    const filterSensitiveLog: (obj: EndpointInput) => any;
}

export interface DataQualityJobInput {
    
    EndpointInput: EndpointInput | undefined;
}
export declare namespace DataQualityJobInput {
    
    const filterSensitiveLog: (obj: DataQualityJobInput) => any;
}
export declare enum ProcessingS3UploadMode {
    CONTINUOUS = "Continuous",
    END_OF_JOB = "EndOfJob"
}

export interface MonitoringS3Output {
    
    S3Uri: string | undefined;
    
    LocalPath: string | undefined;
    
    S3UploadMode?: ProcessingS3UploadMode | string;
}
export declare namespace MonitoringS3Output {
    
    const filterSensitiveLog: (obj: MonitoringS3Output) => any;
}

export interface MonitoringOutput {
    
    S3Output: MonitoringS3Output | undefined;
}
export declare namespace MonitoringOutput {
    
    const filterSensitiveLog: (obj: MonitoringOutput) => any;
}

export interface MonitoringOutputConfig {
    
    MonitoringOutputs: MonitoringOutput[] | undefined;
    
    KmsKeyId?: string;
}
export declare namespace MonitoringOutputConfig {
    
    const filterSensitiveLog: (obj: MonitoringOutputConfig) => any;
}
export declare enum ProcessingInstanceType {
    ML_C4_2XLARGE = "ml.c4.2xlarge",
    ML_C4_4XLARGE = "ml.c4.4xlarge",
    ML_C4_8XLARGE = "ml.c4.8xlarge",
    ML_C4_XLARGE = "ml.c4.xlarge",
    ML_C5_18XLARGE = "ml.c5.18xlarge",
    ML_C5_2XLARGE = "ml.c5.2xlarge",
    ML_C5_4XLARGE = "ml.c5.4xlarge",
    ML_C5_9XLARGE = "ml.c5.9xlarge",
    ML_C5_XLARGE = "ml.c5.xlarge",
    ML_G4DN_12XLARGE = "ml.g4dn.12xlarge",
    ML_G4DN_16XLARGE = "ml.g4dn.16xlarge",
    ML_G4DN_2XLARGE = "ml.g4dn.2xlarge",
    ML_G4DN_4XLARGE = "ml.g4dn.4xlarge",
    ML_G4DN_8XLARGE = "ml.g4dn.8xlarge",
    ML_G4DN_XLARGE = "ml.g4dn.xlarge",
    ML_M4_10XLARGE = "ml.m4.10xlarge",
    ML_M4_16XLARGE = "ml.m4.16xlarge",
    ML_M4_2XLARGE = "ml.m4.2xlarge",
    ML_M4_4XLARGE = "ml.m4.4xlarge",
    ML_M4_XLARGE = "ml.m4.xlarge",
    ML_M5_12XLARGE = "ml.m5.12xlarge",
    ML_M5_24XLARGE = "ml.m5.24xlarge",
    ML_M5_2XLARGE = "ml.m5.2xlarge",
    ML_M5_4XLARGE = "ml.m5.4xlarge",
    ML_M5_LARGE = "ml.m5.large",
    ML_M5_XLARGE = "ml.m5.xlarge",
    ML_P2_16XLARGE = "ml.p2.16xlarge",
    ML_P2_8XLARGE = "ml.p2.8xlarge",
    ML_P2_XLARGE = "ml.p2.xlarge",
    ML_P3_16XLARGE = "ml.p3.16xlarge",
    ML_P3_2XLARGE = "ml.p3.2xlarge",
    ML_P3_8XLARGE = "ml.p3.8xlarge",
    ML_R5_12XLARGE = "ml.r5.12xlarge",
    ML_R5_16XLARGE = "ml.r5.16xlarge",
    ML_R5_24XLARGE = "ml.r5.24xlarge",
    ML_R5_2XLARGE = "ml.r5.2xlarge",
    ML_R5_4XLARGE = "ml.r5.4xlarge",
    ML_R5_8XLARGE = "ml.r5.8xlarge",
    ML_R5_LARGE = "ml.r5.large",
    ML_R5_XLARGE = "ml.r5.xlarge",
    ML_T3_2XLARGE = "ml.t3.2xlarge",
    ML_T3_LARGE = "ml.t3.large",
    ML_T3_MEDIUM = "ml.t3.medium",
    ML_T3_XLARGE = "ml.t3.xlarge"
}

export interface MonitoringClusterConfig {
    
    InstanceCount: number | undefined;
    
    InstanceType: ProcessingInstanceType | string | undefined;
    
    VolumeSizeInGB: number | undefined;
    
    VolumeKmsKeyId?: string;
}
export declare namespace MonitoringClusterConfig {
    
    const filterSensitiveLog: (obj: MonitoringClusterConfig) => any;
}

export interface MonitoringResources {
    
    ClusterConfig: MonitoringClusterConfig | undefined;
}
export declare namespace MonitoringResources {
    
    const filterSensitiveLog: (obj: MonitoringResources) => any;
}

export interface MonitoringNetworkConfig {
    
    EnableInterContainerTrafficEncryption?: boolean;
    
    EnableNetworkIsolation?: boolean;
    
    VpcConfig?: VpcConfig;
}
export declare namespace MonitoringNetworkConfig {
    
    const filterSensitiveLog: (obj: MonitoringNetworkConfig) => any;
}

export interface MonitoringStoppingCondition {
    
    MaxRuntimeInSeconds: number | undefined;
}
export declare namespace MonitoringStoppingCondition {
    
    const filterSensitiveLog: (obj: MonitoringStoppingCondition) => any;
}
export interface CreateDataQualityJobDefinitionRequest {
    
    JobDefinitionName: string | undefined;
    
    DataQualityBaselineConfig?: DataQualityBaselineConfig;
    
    DataQualityAppSpecification: DataQualityAppSpecification | undefined;
    
    DataQualityJobInput: DataQualityJobInput | undefined;
    
    DataQualityJobOutputConfig: MonitoringOutputConfig | undefined;
    
    JobResources: MonitoringResources | undefined;
    
    NetworkConfig?: MonitoringNetworkConfig;
    
    RoleArn: string | undefined;
    
    StoppingCondition?: MonitoringStoppingCondition;
    
    Tags?: Tag[];
}
export declare namespace CreateDataQualityJobDefinitionRequest {
    
    const filterSensitiveLog: (obj: CreateDataQualityJobDefinitionRequest) => any;
}
export interface CreateDataQualityJobDefinitionResponse {
    
    JobDefinitionArn: string | undefined;
}
export declare namespace CreateDataQualityJobDefinitionResponse {
    
    const filterSensitiveLog: (obj: CreateDataQualityJobDefinitionResponse) => any;
}
export declare enum EdgePresetDeploymentType {
    GreengrassV2Component = "GreengrassV2Component"
}

export interface EdgeOutputConfig {
    
    S3OutputLocation: string | undefined;
    
    KmsKeyId?: string;
    
    PresetDeploymentType?: EdgePresetDeploymentType | string;
    
    PresetDeploymentConfig?: string;
}
export declare namespace EdgeOutputConfig {
    
    const filterSensitiveLog: (obj: EdgeOutputConfig) => any;
}
export interface CreateDeviceFleetRequest {
    
    DeviceFleetName: string | undefined;
    
    RoleArn?: string;
    
    Description?: string;
    
    OutputConfig: EdgeOutputConfig | undefined;
    
    Tags?: Tag[];
    
    EnableIotRoleAlias?: boolean;
}
export declare namespace CreateDeviceFleetRequest {
    
    const filterSensitiveLog: (obj: CreateDeviceFleetRequest) => any;
}

export interface JupyterServerAppSettings {
    
    DefaultResourceSpec?: ResourceSpec;
    
    LifecycleConfigArns?: string[];
}
export declare namespace JupyterServerAppSettings {
    
    const filterSensitiveLog: (obj: JupyterServerAppSettings) => any;
}

export interface CustomImage {
    
    ImageName: string | undefined;
    
    ImageVersionNumber?: number;
    
    AppImageConfigName: string | undefined;
}
export declare namespace CustomImage {
    
    const filterSensitiveLog: (obj: CustomImage) => any;
}

export interface KernelGatewayAppSettings {
    
    DefaultResourceSpec?: ResourceSpec;
    
    CustomImages?: CustomImage[];
    
    LifecycleConfigArns?: string[];
}
export declare namespace KernelGatewayAppSettings {
    
    const filterSensitiveLog: (obj: KernelGatewayAppSettings) => any;
}

export interface RSessionAppSettings {
}
export declare namespace RSessionAppSettings {
    
    const filterSensitiveLog: (obj: RSessionAppSettings) => any;
}
export declare enum RStudioServerProAccessStatus {
    Disabled = "DISABLED",
    Enabled = "ENABLED"
}
export declare enum RStudioServerProUserGroup {
    Admin = "R_STUDIO_ADMIN",
    User = "R_STUDIO_USER"
}

export interface RStudioServerProAppSettings {
    
    AccessStatus?: RStudioServerProAccessStatus | string;
    
    UserGroup?: RStudioServerProUserGroup | string;
}
export declare namespace RStudioServerProAppSettings {
    
    const filterSensitiveLog: (obj: RStudioServerProAppSettings) => any;
}
export declare enum NotebookOutputOption {
    Allowed = "Allowed",
    Disabled = "Disabled"
}

export interface SharingSettings {
    
    NotebookOutputOption?: NotebookOutputOption | string;
    
    S3OutputPath?: string;
    
    S3KmsKeyId?: string;
}
export declare namespace SharingSettings {
    
    const filterSensitiveLog: (obj: SharingSettings) => any;
}

export interface TensorBoardAppSettings {
    
    DefaultResourceSpec?: ResourceSpec;
}
export declare namespace TensorBoardAppSettings {
    
    const filterSensitiveLog: (obj: TensorBoardAppSettings) => any;
}

export interface UserSettings {
    
    ExecutionRole?: string;
    
    SecurityGroups?: string[];
    
    SharingSettings?: SharingSettings;
    
    JupyterServerAppSettings?: JupyterServerAppSettings;
    
    KernelGatewayAppSettings?: KernelGatewayAppSettings;
    
    TensorBoardAppSettings?: TensorBoardAppSettings;
    
    RStudioServerProAppSettings?: RStudioServerProAppSettings;
    
    RSessionAppSettings?: RSessionAppSettings;
}
export declare namespace UserSettings {
    
    const filterSensitiveLog: (obj: UserSettings) => any;
}

export interface RStudioServerProDomainSettings {
    
    DomainExecutionRoleArn: string | undefined;
    
    RStudioConnectUrl?: string;
    
    RStudioPackageManagerUrl?: string;
    
    DefaultResourceSpec?: ResourceSpec;
}
export declare namespace RStudioServerProDomainSettings {
    
    const filterSensitiveLog: (obj: RStudioServerProDomainSettings) => any;
}

export interface DomainSettings {
    
    SecurityGroupIds?: string[];
    
    RStudioServerProDomainSettings?: RStudioServerProDomainSettings;
}
export declare namespace DomainSettings {
    
    const filterSensitiveLog: (obj: DomainSettings) => any;
}
export interface CreateDomainRequest {
    
    DomainName: string | undefined;
    
    AuthMode: AuthMode | string | undefined;
    
    DefaultUserSettings: UserSettings | undefined;
    
    SubnetIds: string[] | undefined;
    
    VpcId: string | undefined;
    
    Tags?: Tag[];
    
    AppNetworkAccessType?: AppNetworkAccessType | string;
    
    HomeEfsFileSystemKmsKeyId?: string;
    
    KmsKeyId?: string;
    
    AppSecurityGroupManagement?: AppSecurityGroupManagement | string;
    
    DomainSettings?: DomainSettings;
}
export declare namespace CreateDomainRequest {
    
    const filterSensitiveLog: (obj: CreateDomainRequest) => any;
}
export interface CreateDomainResponse {
    
    DomainArn?: string;
    
    Url?: string;
}
export declare namespace CreateDomainResponse {
    
    const filterSensitiveLog: (obj: CreateDomainResponse) => any;
}
export interface CreateEdgePackagingJobRequest {
    
    EdgePackagingJobName: string | undefined;
    
    CompilationJobName: string | undefined;
    
    ModelName: string | undefined;
    
    ModelVersion: string | undefined;
    
    RoleArn: string | undefined;
    
    OutputConfig: EdgeOutputConfig | undefined;
    
    ResourceKey?: string;
    
    Tags?: Tag[];
}
export declare namespace CreateEdgePackagingJobRequest {
    
    const filterSensitiveLog: (obj: CreateEdgePackagingJobRequest) => any;
}

export interface DeploymentConfig {
    
    BlueGreenUpdatePolicy: BlueGreenUpdatePolicy | undefined;
    
    AutoRollbackConfiguration?: AutoRollbackConfig;
}
export declare namespace DeploymentConfig {
    
    const filterSensitiveLog: (obj: DeploymentConfig) => any;
}
export interface CreateEndpointInput {
    
    EndpointName: string | undefined;
    
    EndpointConfigName: string | undefined;
    
    DeploymentConfig?: DeploymentConfig;
    
    Tags?: Tag[];
}
export declare namespace CreateEndpointInput {
    
    const filterSensitiveLog: (obj: CreateEndpointInput) => any;
}
export interface CreateEndpointOutput {
    
    EndpointArn: string | undefined;
}
export declare namespace CreateEndpointOutput {
    
    const filterSensitiveLog: (obj: CreateEndpointOutput) => any;
}

export interface DataCaptureConfig {
    
    EnableCapture?: boolean;
    
    InitialSamplingPercentage: number | undefined;
    
    DestinationS3Uri: string | undefined;
    
    KmsKeyId?: string;
    
    CaptureOptions: CaptureOption[] | undefined;
    
    CaptureContentTypeHeader?: CaptureContentTypeHeader;
}
export declare namespace DataCaptureConfig {
    
    const filterSensitiveLog: (obj: DataCaptureConfig) => any;
}
export declare enum ProductionVariantAcceleratorType {
    ML_EIA1_LARGE = "ml.eia1.large",
    ML_EIA1_MEDIUM = "ml.eia1.medium",
    ML_EIA1_XLARGE = "ml.eia1.xlarge",
    ML_EIA2_LARGE = "ml.eia2.large",
    ML_EIA2_MEDIUM = "ml.eia2.medium",
    ML_EIA2_XLARGE = "ml.eia2.xlarge"
}

export interface ProductionVariantCoreDumpConfig {
    
    DestinationS3Uri: string | undefined;
    
    KmsKeyId?: string;
}
export declare namespace ProductionVariantCoreDumpConfig {
    
    const filterSensitiveLog: (obj: ProductionVariantCoreDumpConfig) => any;
}

export interface ProductionVariantServerlessConfig {
    
    MemorySizeInMB: number | undefined;
    
    MaxConcurrency: number | undefined;
}
export declare namespace ProductionVariantServerlessConfig {
    
    const filterSensitiveLog: (obj: ProductionVariantServerlessConfig) => any;
}

export interface ProductionVariant {
    
    VariantName: string | undefined;
    
    ModelName: string | undefined;
    
    InitialInstanceCount?: number;
    
    InstanceType?: ProductionVariantInstanceType | string;
    
    InitialVariantWeight?: number;
    
    AcceleratorType?: ProductionVariantAcceleratorType | string;
    
    CoreDumpConfig?: ProductionVariantCoreDumpConfig;
    
    ServerlessConfig?: ProductionVariantServerlessConfig;
}
export declare namespace ProductionVariant {
    
    const filterSensitiveLog: (obj: ProductionVariant) => any;
}
export interface CreateEndpointConfigInput {
    
    EndpointConfigName: string | undefined;
    
    ProductionVariants: ProductionVariant[] | undefined;
    
    DataCaptureConfig?: DataCaptureConfig;
    
    Tags?: Tag[];
    
    KmsKeyId?: string;
    
    AsyncInferenceConfig?: AsyncInferenceConfig;
}
export declare namespace CreateEndpointConfigInput {
    
    const filterSensitiveLog: (obj: CreateEndpointConfigInput) => any;
}
export interface CreateEndpointConfigOutput {
    
    EndpointConfigArn: string | undefined;
}
export declare namespace CreateEndpointConfigOutput {
    
    const filterSensitiveLog: (obj: CreateEndpointConfigOutput) => any;
}
export interface CreateExperimentRequest {
    
    ExperimentName: string | undefined;
    
    DisplayName?: string;
    
    Description?: string;
    
    Tags?: Tag[];
}
export declare namespace CreateExperimentRequest {
    
    const filterSensitiveLog: (obj: CreateExperimentRequest) => any;
}
export interface CreateExperimentResponse {
    
    ExperimentArn?: string;
}
export declare namespace CreateExperimentResponse {
    
    const filterSensitiveLog: (obj: CreateExperimentResponse) => any;
}
export declare enum FeatureType {
    FRACTIONAL = "Fractional",
    INTEGRAL = "Integral",
    STRING = "String"
}

export interface FeatureDefinition {
    
    FeatureName?: string;
    
    FeatureType?: FeatureType | string;
}
export declare namespace FeatureDefinition {
    
    const filterSensitiveLog: (obj: FeatureDefinition) => any;
}

export interface DataCatalogConfig {
    
    TableName: string | undefined;
    
    Catalog: string | undefined;
    
    Database: string | undefined;
}
export declare namespace DataCatalogConfig {
    
    const filterSensitiveLog: (obj: DataCatalogConfig) => any;
}

export interface S3StorageConfig {
    
    S3Uri: string | undefined;
    
    KmsKeyId?: string;
    
    ResolvedOutputS3Uri?: string;
}
export declare namespace S3StorageConfig {
    
    const filterSensitiveLog: (obj: S3StorageConfig) => any;
}

export interface OfflineStoreConfig {
    
    S3StorageConfig: S3StorageConfig | undefined;
    
    DisableGlueTableCreation?: boolean;
    
    DataCatalogConfig?: DataCatalogConfig;
}
export declare namespace OfflineStoreConfig {
    
    const filterSensitiveLog: (obj: OfflineStoreConfig) => any;
}

export interface OnlineStoreSecurityConfig {
    
    KmsKeyId?: string;
}
export declare namespace OnlineStoreSecurityConfig {
    
    const filterSensitiveLog: (obj: OnlineStoreSecurityConfig) => any;
}

export interface OnlineStoreConfig {
    
    SecurityConfig?: OnlineStoreSecurityConfig;
    
    EnableOnlineStore?: boolean;
}
export declare namespace OnlineStoreConfig {
    
    const filterSensitiveLog: (obj: OnlineStoreConfig) => any;
}
export interface CreateFeatureGroupRequest {
    
    FeatureGroupName: string | undefined;
    
    RecordIdentifierFeatureName: string | undefined;
    
    EventTimeFeatureName: string | undefined;
    
    FeatureDefinitions: FeatureDefinition[] | undefined;
    
    OnlineStoreConfig?: OnlineStoreConfig;
    
    OfflineStoreConfig?: OfflineStoreConfig;
    
    RoleArn?: string;
    
    Description?: string;
    
    Tags?: Tag[];
}
export declare namespace CreateFeatureGroupRequest {
    
    const filterSensitiveLog: (obj: CreateFeatureGroupRequest) => any;
}
export interface CreateFeatureGroupResponse {
    
    FeatureGroupArn: string | undefined;
}
export declare namespace CreateFeatureGroupResponse {
    
    const filterSensitiveLog: (obj: CreateFeatureGroupResponse) => any;
}

export interface HumanLoopActivationConditionsConfig {
    
    HumanLoopActivationConditions: __LazyJsonString | string | undefined;
}
export declare namespace HumanLoopActivationConditionsConfig {
    
    const filterSensitiveLog: (obj: HumanLoopActivationConditionsConfig) => any;
}

export interface HumanLoopActivationConfig {
    
    HumanLoopActivationConditionsConfig: HumanLoopActivationConditionsConfig | undefined;
}
export declare namespace HumanLoopActivationConfig {
    
    const filterSensitiveLog: (obj: HumanLoopActivationConfig) => any;
}

export interface USD {
    
    Dollars?: number;
    
    Cents?: number;
    
    TenthFractionsOfACent?: number;
}
export declare namespace USD {
    
    const filterSensitiveLog: (obj: USD) => any;
}

export interface PublicWorkforceTaskPrice {
    
    AmountInUsd?: USD;
}
export declare namespace PublicWorkforceTaskPrice {
    
    const filterSensitiveLog: (obj: PublicWorkforceTaskPrice) => any;
}

export interface HumanLoopConfig {
    
    WorkteamArn: string | undefined;
    
    HumanTaskUiArn: string | undefined;
    
    TaskTitle: string | undefined;
    
    TaskDescription: string | undefined;
    
    TaskCount: number | undefined;
    
    TaskAvailabilityLifetimeInSeconds?: number;
    
    TaskTimeLimitInSeconds?: number;
    
    TaskKeywords?: string[];
    
    PublicWorkforceTaskPrice?: PublicWorkforceTaskPrice;
}
export declare namespace HumanLoopConfig {
    
    const filterSensitiveLog: (obj: HumanLoopConfig) => any;
}

export interface HumanLoopRequestSource {
    
    AwsManagedHumanLoopRequestSource: AwsManagedHumanLoopRequestSource | string | undefined;
}
export declare namespace HumanLoopRequestSource {
    
    const filterSensitiveLog: (obj: HumanLoopRequestSource) => any;
}

export interface FlowDefinitionOutputConfig {
    
    S3OutputPath: string | undefined;
    
    KmsKeyId?: string;
}
export declare namespace FlowDefinitionOutputConfig {
    
    const filterSensitiveLog: (obj: FlowDefinitionOutputConfig) => any;
}
export interface CreateFlowDefinitionRequest {
    
    FlowDefinitionName: string | undefined;
    
    HumanLoopRequestSource?: HumanLoopRequestSource;
    
    HumanLoopActivationConfig?: HumanLoopActivationConfig;
    
    HumanLoopConfig: HumanLoopConfig | undefined;
    
    OutputConfig: FlowDefinitionOutputConfig | undefined;
    
    RoleArn: string | undefined;
    
    Tags?: Tag[];
}
export declare namespace CreateFlowDefinitionRequest {
    
    const filterSensitiveLog: (obj: CreateFlowDefinitionRequest) => any;
}
export interface CreateFlowDefinitionResponse {
    
    FlowDefinitionArn: string | undefined;
}
export declare namespace CreateFlowDefinitionResponse {
    
    const filterSensitiveLog: (obj: CreateFlowDefinitionResponse) => any;
}

export interface UiTemplate {
    
    Content: string | undefined;
}
export declare namespace UiTemplate {
    
    const filterSensitiveLog: (obj: UiTemplate) => any;
}
export interface CreateHumanTaskUiRequest {
    
    HumanTaskUiName: string | undefined;
    
    UiTemplate: UiTemplate | undefined;
    
    Tags?: Tag[];
}
export declare namespace CreateHumanTaskUiRequest {
    
    const filterSensitiveLog: (obj: CreateHumanTaskUiRequest) => any;
}
export interface CreateHumanTaskUiResponse {
    
    HumanTaskUiArn: string | undefined;
}
export declare namespace CreateHumanTaskUiResponse {
    
    const filterSensitiveLog: (obj: CreateHumanTaskUiResponse) => any;
}

export interface IntegerParameterRange {
    
    Name: string | undefined;
    
    MinValue: string | undefined;
    
    MaxValue: string | undefined;
    
    ScalingType?: HyperParameterScalingType | string;
}
export declare namespace IntegerParameterRange {
    
    const filterSensitiveLog: (obj: IntegerParameterRange) => any;
}

export interface ParameterRanges {
    
    IntegerParameterRanges?: IntegerParameterRange[];
    
    ContinuousParameterRanges?: ContinuousParameterRange[];
    
    CategoricalParameterRanges?: CategoricalParameterRange[];
}
export declare namespace ParameterRanges {
    
    const filterSensitiveLog: (obj: ParameterRanges) => any;
}

export interface ResourceLimits {
    
    MaxNumberOfTrainingJobs: number | undefined;
    
    MaxParallelTrainingJobs: number | undefined;
}
export declare namespace ResourceLimits {
    
    const filterSensitiveLog: (obj: ResourceLimits) => any;
}
export declare enum HyperParameterTuningJobStrategyType {
    BAYESIAN = "Bayesian",
    RANDOM = "Random"
}
export declare enum TrainingJobEarlyStoppingType {
    AUTO = "Auto",
    OFF = "Off"
}

export interface TuningJobCompletionCriteria {
    
    TargetObjectiveMetricValue: number | undefined;
}
export declare namespace TuningJobCompletionCriteria {
    
    const filterSensitiveLog: (obj: TuningJobCompletionCriteria) => any;
}

export interface HyperParameterTuningJobConfig {
    
    Strategy: HyperParameterTuningJobStrategyType | string | undefined;
    
    HyperParameterTuningJobObjective?: HyperParameterTuningJobObjective;
    
    ResourceLimits: ResourceLimits | undefined;
    
    ParameterRanges?: ParameterRanges;
    
    TrainingJobEarlyStoppingType?: TrainingJobEarlyStoppingType | string;
    
    TuningJobCompletionCriteria?: TuningJobCompletionCriteria;
}
export declare namespace HyperParameterTuningJobConfig {
    
    const filterSensitiveLog: (obj: HyperParameterTuningJobConfig) => any;
}

export interface HyperParameterAlgorithmSpecification {
    
    TrainingImage?: string;
    
    TrainingInputMode: TrainingInputMode | string | undefined;
    
    AlgorithmName?: string;
    
    MetricDefinitions?: MetricDefinition[];
}
export declare namespace HyperParameterAlgorithmSpecification {
    
    const filterSensitiveLog: (obj: HyperParameterAlgorithmSpecification) => any;
}

export interface RetryStrategy {
    
    MaximumRetryAttempts: number | undefined;
}
export declare namespace RetryStrategy {
    
    const filterSensitiveLog: (obj: RetryStrategy) => any;
}

export interface HyperParameterTrainingJobDefinition {
    
    DefinitionName?: string;
    
    TuningObjective?: HyperParameterTuningJobObjective;
    
    HyperParameterRanges?: ParameterRanges;
    
    StaticHyperParameters?: {
        [key: string]: string;
    };
    
    AlgorithmSpecification: HyperParameterAlgorithmSpecification | undefined;
    
    RoleArn: string | undefined;
    
    InputDataConfig?: Channel[];
    
    VpcConfig?: VpcConfig;
    
    OutputDataConfig: OutputDataConfig | undefined;
    
    ResourceConfig: ResourceConfig | undefined;
    
    StoppingCondition: StoppingCondition | undefined;
    
    EnableNetworkIsolation?: boolean;
    
    EnableInterContainerTrafficEncryption?: boolean;
    
    EnableManagedSpotTraining?: boolean;
    
    CheckpointConfig?: CheckpointConfig;
    
    RetryStrategy?: RetryStrategy;
}
export declare namespace HyperParameterTrainingJobDefinition {
    
    const filterSensitiveLog: (obj: HyperParameterTrainingJobDefinition) => any;
}

export interface ParentHyperParameterTuningJob {
    
    HyperParameterTuningJobName?: string;
}
export declare namespace ParentHyperParameterTuningJob {
    
    const filterSensitiveLog: (obj: ParentHyperParameterTuningJob) => any;
}
export declare enum HyperParameterTuningJobWarmStartType {
    IDENTICAL_DATA_AND_ALGORITHM = "IdenticalDataAndAlgorithm",
    TRANSFER_LEARNING = "TransferLearning"
}

export interface HyperParameterTuningJobWarmStartConfig {
    
    ParentHyperParameterTuningJobs: ParentHyperParameterTuningJob[] | undefined;
    
    WarmStartType: HyperParameterTuningJobWarmStartType | string | undefined;
}
export declare namespace HyperParameterTuningJobWarmStartConfig {
    
    const filterSensitiveLog: (obj: HyperParameterTuningJobWarmStartConfig) => any;
}
export interface CreateHyperParameterTuningJobRequest {
    
    HyperParameterTuningJobName: string | undefined;
    
    HyperParameterTuningJobConfig: HyperParameterTuningJobConfig | undefined;
    
    TrainingJobDefinition?: HyperParameterTrainingJobDefinition;
    
    TrainingJobDefinitions?: HyperParameterTrainingJobDefinition[];
    
    WarmStartConfig?: HyperParameterTuningJobWarmStartConfig;
    
    Tags?: Tag[];
}
export declare namespace CreateHyperParameterTuningJobRequest {
    
    const filterSensitiveLog: (obj: CreateHyperParameterTuningJobRequest) => any;
}
export interface CreateHyperParameterTuningJobResponse {
    
    HyperParameterTuningJobArn: string | undefined;
}
export declare namespace CreateHyperParameterTuningJobResponse {
    
    const filterSensitiveLog: (obj: CreateHyperParameterTuningJobResponse) => any;
}
export interface CreateImageRequest {
    
    Description?: string;
    
    DisplayName?: string;
    
    ImageName: string | undefined;
    
    RoleArn: string | undefined;
    
    Tags?: Tag[];
}
export declare namespace CreateImageRequest {
    
    const filterSensitiveLog: (obj: CreateImageRequest) => any;
}
export interface CreateImageResponse {
    
    ImageArn?: string;
}
export declare namespace CreateImageResponse {
    
    const filterSensitiveLog: (obj: CreateImageResponse) => any;
}
export interface CreateImageVersionRequest {
    
    BaseImage: string | undefined;
    
    ClientToken?: string;
    
    ImageName: string | undefined;
}
export declare namespace CreateImageVersionRequest {
    
    const filterSensitiveLog: (obj: CreateImageVersionRequest) => any;
}
export interface CreateImageVersionResponse {
    
    ImageVersionArn?: string;
}
export declare namespace CreateImageVersionResponse {
    
    const filterSensitiveLog: (obj: CreateImageVersionResponse) => any;
}

export interface EnvironmentParameterRanges {
    
    CategoricalParameterRanges?: CategoricalParameter[];
}
export declare namespace EnvironmentParameterRanges {
    
    const filterSensitiveLog: (obj: EnvironmentParameterRanges) => any;
}
